@@ -41,15 +41,9 @@ void SetCurrentFont (BFont_Info * Font);
 /* Returns the font height */
 int FontHeight (BFont_Info * Font);
 
-/* Change the font height */
-void SetFontHeight (BFont_Info * Font, int height);
-
 /* Returns the character width of the specified font */
 int CharWidth (BFont_Info * Font, unsigned char c);
 
-/* Write a single character on the "Surface" with the current font */
-int PutChar (SDL_Surface * Surface, int x, int y, unsigned char c);
-
 /* Write a single character on the "Surface" with the specified font */
 int PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, unsigned char c);
 
@@ -59,6 +53,12 @@ int TextWidth (char *text);
 /* Returns the width, in pixels, of the text calculated with the specified font*/
 int TextWidthFont (BFont_Info * Font, char *text);
 
+/* Returns the index of the last character than is inside the width limit, with the current font */
+int LimitTextWidth (char *text, int limit);
+
+/* Returns the index of the last character than is inside the width limit */
+int LimitTextWidthFont (BFont_Info * Font, char *text, int limit);
+
 /* Write a string on the "Surface" with the current font */
 void PutString (SDL_Surface * Surface, int x, int y, char *text);
 
@@ -116,6 +116,3 @@ void LeftPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
 void JustifiedPrintString (SDL_Surface * Surface, int y, const char *fmt, ...);
 void JustifiedPrintStringFont (SDL_Surface * Surface, BFont_Info * Font,
 			       int y, const char *fmt, ...);
-
-/* Returns a new font colored with the color (r,g,b) */
-BFont_Info *SetFontColor (BFont_Info * Font, Uint8 r, Uint8 g, Uint8 b);
