@@ -126,43 +126,43 @@ void DoMeleeDamage (void)
     int i;
     melee_shot * CurMelS;
 
-    for ( CurMelS = AllMeleeShots, i = 0; i < MAX_MELEE_SHOTS; CurMelS++, i++)
-	{
+    /* Browse all melee shots */
+    for ( CurMelS = AllMeleeShots, i = 0; i < MAX_MELEE_SHOTS; CurMelS++, i++)	{
 	if ( CurMelS -> attack_target_type == ATTACK_TARGET_IS_NOTHING )
 	    continue;
 
-	if ( CurMelS -> attack_target_type == ATTACK_TARGET_IS_ENEMY )
-	    { /* hit enemy*/
+	if ( CurMelS -> attack_target_type == ATTACK_TARGET_IS_ENEMY )  { 
+	    /* Attack an enemy */
 	    enemy * tg = enemy_resolve_address(CurMelS -> bot_target_n, &CurMelS->bot_target_addr);
-	    if ( ! tg )
-		{
+	    if ( ! tg ) {
 		ErrorMessage(__FUNCTION__, "Melee shot was set to ATTACK_TARGET_IS_ENEMY but had no targetted enemy. Deleting.\n", NO_NEED_TO_INFORM, IS_WARNING_ONLY);
 		delete_melee_shot(CurMelS);
 		continue;
-		}
+	    }
 
-	    if ( tg -> energy <= 0 )
-		{
+	    if ( tg -> energy <= 0 ) {
 		// our enemy is already dead ! 
 		delete_melee_shot(CurMelS);
 		continue;
-		}
-
-	    if ( ((float) Druidmap [ tg -> type ] . monster_level * (float)MyRandom ( 100 ) < CurMelS->to_hit ))
-		{
-		hit_enemy(tg, CurMelS->damage, CurMelS->mine ? 1 : 0, CurMelS->owner, CurMelS->mine ? 1 : 0);
-		}
 	    }
-	else if ( CurMelS -> attack_target_type == ATTACK_TARGET_IS_PLAYER )
-	    { /* hit player */
-	    if ( MyRandom ( 100 ) <= Me . lv_1_bot_will_hit_percentage * CurMelS->level)
-		{
+
+	    if ( ((float) Druidmap [ tg -> type ] . monster_level * (float)MyRandom ( 100 ) < CurMelS->to_hit )) {
+		if (CurMelS->mine) {
+		}
+		hit_enemy(tg, CurMelS->damage, CurMelS->mine ? 1 : 0, CurMelS->owner, CurMelS->mine ? 1 : 0);
+	    } else 
+		if (CurMelS->mine) {
+		}
+	}
+	else if ( CurMelS -> attack_target_type == ATTACK_TARGET_IS_PLAYER ) { 
+	    /* hit player */
+	    if ( MyRandom ( 100 ) <= Me . lv_1_bot_will_hit_percentage * CurMelS->level) {
 		Me . energy -= CurMelS -> damage;
 		if ( MyRandom ( 100 ) <= 20 ) tux_scream_sound ( );
-		}
 	    }
-	delete_melee_shot(CurMelS);
 	}
+	delete_melee_shot(CurMelS);
+    }
 }
 
 
@@ -459,7 +459,7 @@ MoveActiveSpells (void)
 		final_point . x = AllActiveSpells [ i ] . spell_center . x + Displacement . x ;
 		final_point . y = AllActiveSpells [ i ] . spell_center . y + Displacement . y ;
 		// current_active_direction = rintf ( ( Angle  ) * (float) RADIAL_SPELL_DIRECTIONS / 360.0 ); 
-		if ( ! SinglePointColldet ( final_point . x , final_point . y , Me . pos . z, &FilterFlyable ) )
+		if ( ! SinglePointColldet ( final_point . x , final_point . y , Me . pos . z, &FlyablePassFilter ) )
 		    AllActiveSpells [ i ] . active_directions [ direction_index ] = FALSE ;
 	    }
 
@@ -654,7 +654,7 @@ void
 check_bullet_background_collisions ( bullet* CurBullet , int num )
 {
   // Check for collision with background
-  if ( ! SinglePointColldet ( CurBullet -> pos . x , CurBullet -> pos . y , CurBullet -> pos . z, &FilterFlyable ) )
+  if ( ! SinglePointColldet ( CurBullet -> pos . x , CurBullet -> pos . y , CurBullet -> pos . z, &FlyablePassFilter ) )
     {
       if ( CurBullet->ignore_wall_collisions )
 	{
@@ -719,7 +719,7 @@ check_bullet_player_collisions ( bullet* CurBullet , int num )
       // Of course only active players and players on the same level
       // may be checked!
       //
-      if ( Me . status == INFOUT || Me . pos . z != CurBullet -> pos . z ) return;
+      if ( Me . energy <= 0 || Me . pos . z != CurBullet -> pos . z ) return;
       
       //--------------------
       // A player is supposed not to hit himself with his bullets, so we may
@@ -754,7 +754,6 @@ check_bullet_enemy_collisions ( bullet* CurBullet , int num )
 {
     double xdist, ydist;
     int level = CurBullet -> pos.z ;
-    static int FBTZaehler = 0;
     
     if ( CurBullet -> type == INFOUT ) 
 	fprintf(stderr, "Caca\n");
@@ -792,10 +791,6 @@ check_bullet_enemy_collisions ( bullet* CurBullet , int num )
 		StartBlast ( CurBullet -> pos.x , CurBullet -> pos.y , CurBullet -> pos.z , BULLETBLAST, 0 );
 	    else DeleteBullet( num , TRUE ); // we want a bullet-explosion
 
-	    if (!CurBullet->mine)
-		{
-		FBTZaehler++;
-		}
 	    return;
 	    } // if distance low enough to possibly be at hit
 	} 
@@ -968,7 +963,7 @@ CheckBlastCollisions (int num)
     // Now we check, if perhaps the influencer has stepped into the area
     // of effect of this one blast.  Then he'll get burnt ;)
     // 
-    if ( (Me.status != INFOUT) && 
+    if ( (Me.energy > 0) && 
 	 ( fabsf (Me.pos.x - CurBlast->pos.x ) < Blast_Radius ) &&
 	 ( fabsf (Me.pos.y - CurBlast->pos.y ) < Blast_Radius ) )
     {
