@@ -108,7 +108,7 @@ static inline float calc_distance_seg_point_normalized ( float x1, float y1, flo
  * This colldet filter is used to ignore the obstacles (such as doors)
  * that can be traversed by walking bot.
  */
-int FilterWalkableCallback(colldet_filter* this, obstacle* obs, int obs_idx )
+int WalkablePassFilterCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 {
 	if ( obstacle_map[obs->type].flags & IS_WALKABLE ) return TRUE;
 
@@ -116,13 +116,13 @@ int FilterWalkableCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 	
 	return FALSE;
 }
-colldet_filter FilterWalkable = { FilterWalkableCallback, NULL, NULL };
+colldet_filter WalkablePassFilter = { WalkablePassFilterCallback, NULL, NULL };
 
 /**
  * This colldet filter is used to ignore the obstacles (such as water)
  * that can be traversed by a flying object.
  */
-int FilterFlyableCallback(colldet_filter* this, obstacle* obs, int obs_idx )
+int FlyablePassFilterCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 {
 	if ( obstacle_map[obs->type].flags & GROUND_LEVEL ) return TRUE;
 
@@ -130,14 +130,14 @@ int FilterFlyableCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 	
 	return FALSE;
 }
-colldet_filter FilterFlyable = { FilterFlyableCallback, NULL, NULL };
+colldet_filter FlyablePassFilter = { FlyablePassFilterCallback, NULL, NULL };
 
 /**
  * This colldet filter is used to ignore the obstacles
  * that can be traversed by light.
  * Thus, it merely checks for visibility.
  */
-int FilterVisibleCallback(colldet_filter* this, obstacle* obs, int obs_idx )
+int VisiblePassFilterCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 {
 	if ( ! ( obstacle_map[obs->type].flags & BLOCKS_VISION_TOO) ) return TRUE;
 
@@ -145,13 +145,13 @@ int FilterVisibleCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 	
 	return FALSE;
 }
-colldet_filter FilterVisible = { FilterVisibleCallback, NULL, NULL };
+colldet_filter VisiblePassFilter = { VisiblePassFilterCallback, NULL, NULL };
 
 /**
  * This colldet filter is used to ignore a given obstacle during
  * collision detection
  */
-int FilterObstacleByIdCallback(colldet_filter* this, obstacle* obs, int obs_idx )
+int ObstacleByIdPassFilterCallback(colldet_filter* this, obstacle* obs, int obs_idx )
 {
 	if ( obs_idx == *(int*)(this->data) ) return TRUE;
 
@@ -159,7 +159,7 @@ int FilterObstacleByIdCallback(colldet_filter* this, obstacle* obs, int obs_idx
 
 	return FALSE;
 }
-colldet_filter FilterObstacleById = { FilterObstacleByIdCallback, NULL, NULL };
+colldet_filter ObstacleByIdPassFilter = { ObstacleByIdPassFilterCallback, NULL, NULL };
 
 /**
  * This function checks if the connection between two points is free of
@@ -171,31 +171,36 @@ colldet_filter FilterObstacleById = { FilterObstacleByIdCallback, NULL, NULL };
  * OBSTACLES ARE NOT TAKEN INTO CONSIDERATION, ONLY DROIDS!!!
  *
  */
-int 
-CheckIfWayIsFreeOfDroids (char test_tux, float x1 , float y1 , float x2 , float y2 , int OurLevel , 
-					  Enemy ExceptedRobot ) 
+int CheckIfWayIsFreeOfDroids ( float x1 , float y1 , float x2 , float y2 , int OurLevel , freeway_context* ctx )
 {
-    const float Druid_Radius = 0.5;
-     
-    float x2n = x2;
-    float y2n = y2;
-    normalize_vect ( x1, y1, &x2n, &y2n);
+	const float Druid_Radius = 0.5;
 
-    enemy * this_enemy;
-    BROWSE_LEVEL_BOTS(this_enemy, OurLevel)
+	float x2n = x2;
+	float y2n = y2;
+	normalize_vect ( x1, y1, &x2n, &y2n);
+
+	if ( ctx->check_tux )
 	{
-	if (( this_enemy -> pure_wait > 0 )  || (this_enemy == ExceptedRobot ) )
-	    continue;
-
-	float dist = calc_distance_seg_point_normalized ( x1, y1, x2, y2, x2n, y2n, this_enemy->pos.x, this_enemy->pos.y);
-
-	if ( dist < Druid_Radius )
-	    return FALSE;
+		float dist = calc_distance_seg_point_normalized ( x1, y1, x2, y2, x2n, y2n, Me.pos.x, Me.pos.y);
+		if ( dist < Druid_Radius ) return FALSE;
 	}
 
-    return TRUE;
+	enemy * this_enemy;
+	BROWSE_LEVEL_BOTS(this_enemy, OurLevel)
+	{
+		if ( ( this_enemy->pure_wait > 0 ) ||
+		     ( ctx->except_bots[0] != NULL && ctx->except_bots[0] == this_enemy ) ||
+		     ( ctx->except_bots[1] != NULL && ctx->except_bots[1] == this_enemy ) )
+			continue;
 
-}; // CheckIfWayIsFreeOfDroids ( char test_tux, float x1 , float y1 , float x2 , float y2 , int OurLevel , int ExceptedDroid )
+		float dist = calc_distance_seg_point_normalized ( x1, y1, x2, y2, x2n, y2n, this_enemy->pos.x, this_enemy->pos.y);
+
+		if ( dist < Druid_Radius ) return FALSE;
+	}
+
+	return TRUE;
+
+}; // CheckIfWayIsFreeOfDroids ( float x1 , float y1 , float x2 , float y2 , int OurLevel , freeway_ctx* ctx )
 
 enum {
 	RECT_IN = 0,
