@@ -82,9 +82,6 @@ extern list_head_t dead_bots_head;
 extern list_head_t level_bots_head[MAX_LEVELS];
 
 EXTERN spell_active AllActiveSpells[ MAX_ACTIVE_SPELLS ];
-EXTERN event_trigger AllEventTriggers[ MAX_EVENT_TRIGGERS ];
-EXTERN triggered_action AllTriggeredActions[ MAX_TRIGGERED_ACTIONS_IN_GAME ];
-
 EXTERN ship curShip;		/* the current ship-data */
 
 EXTERN bullet AllBullets[MAXBULLETS + 10];
@@ -110,11 +107,6 @@ EXTERN int command_line_override_for_screen_resolution;
 EXTERN char* mission_diary_texts [ MAX_MISSIONS_IN_GAME ] [ MAX_MISSION_DESCRIPTION_TEXTS ] ;
 EXTERN char* character_descriptions [ MAX_PERSONS ] ;
 
-#ifdef HAVE_LIBGL
-EXTERN GLuint all_freedroid_textures [ MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE ] ;
-EXTERN int next_texture_index_to_use ;
-#endif
-
 EXTERN char previous_part_strings [ ALL_PART_GROUPS ] [ 50 ] ;
 EXTERN mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] ;
 EXTERN int Item_Held_In_Hand;
@@ -167,6 +159,27 @@ EXTERN int rmask;
 #endif
 EXTERN light_radius_config LightRadiusConfig;
 
+#undef EXTERN
+#ifdef _event_c
+#define EXTERN
+#else
+#define EXTERN extern
+#endif
+EXTERN event_trigger AllEventTriggers[ MAX_EVENT_TRIGGERS ];
+
+#undef EXTERN
+#ifdef _chat_c
+#define EXTERN
+#else
+#define EXTERN extern
+#endif
+int chat_control_next_node; //what is the next node to use?
+int chat_control_end_dialog; //end current dialog?
+int chat_control_partner_code; //our partner code to access chat flags from Lua
+int chat_control_partner_started; //the dialog partner is the one who started the talk
+enemy *chat_control_chat_droid; //droid we are chatting with
+dialogue_option ChatRoster[MAX_DIALOGUE_OPTIONS_IN_ROSTER];
+
 #undef EXTERN
 #ifdef _sound_c
 #define EXTERN
@@ -268,8 +281,6 @@ EXTERN SDL_Rect Droid_Image_Window;
 #define EXTERN extern
 #endif
 
-EXTERN obstacle* level_editor_marked_obstacle;
-
 #undef EXTERN
 #ifdef _input_c
 #define EXTERN
