@@ -81,8 +81,6 @@ clear_out_arrays_for_fresh_game ( void )
 {
     int i;
 
-    level_editor_marked_obstacle = NULL ;
-
     for ( i = 0; i < MAX_MELEE_SHOTS; i ++)
 	delete_melee_shot(&AllMeleeShots[i]);
 
@@ -130,31 +128,31 @@ init_character_descriptions ( void )
 
     character_descriptions [ PERSON_CHA ] = _("Hmm... This must be the token town sage.");
 
-    character_descriptions [ PERSON_SORENSON ] = _("You see a legend. Sorenson Clark. One of the best human programmers that have ever lived. Just like Paganini she is said to have sold her soul to the devil for her skill. Whatever is the truth, her code is like magic, and there is no denying that.");
+    character_descriptions [ PERSON_SORENSON ] = _("You see a legend. Sorenson Clark. One of the best human programmers that has ever lived. Just like Paganini, she is said to have sold her soul to the devil for her skill. Whatever the truth is, her code is like magic, and there is no denying that.");
 
-    character_descriptions [ PERSON_KEVIN ] = _("He is either a college student, a drug addict or a hacker. I bet he did not have a warm meal for days, he looks totally malnourished. His body keeps twitching. Must be the caffeine. I hope.");
+    character_descriptions [ PERSON_KEVIN ] = _("He is either a college student, a drug addict or a hacker. You bet he has not had a warm meal for days, he looks totally malnourished. His body keeps twitching. Must be the caffeine. You hope.");
 
-    character_descriptions [ PERSON_BENDER ] = _("Don't do steroids or you will be just like him.");
+    character_descriptions [ PERSON_BENDER ] = _("Don't do steroids, or you will be just like him.");
 
     character_descriptions [ PERSON_614 ] = _("There are at least 614 reasons to stay away from the 614 bot battle platform. There are also 614 reasons why a 614 bot battle platform can be your best friend during combat...");
 
-    character_descriptions [ PERSON_FRANCIS ] = _("Francis is not looking so good today. His tattered coat is not looking that much better either. The war is taking its toll on them both.");
+    character_descriptions [ PERSON_FRANCIS ] = _("Francis is not looking so good today. His tattered coat is not looking that much better. The war is taking its toll on them both.");
 
     character_descriptions [ PERSON_DUNCAN ] = _("What a strange person. He does not seem to really fit into this reality. There is something very eerie about him. And frightening.");
 
-    character_descriptions [ PERSON_BRUCE ] = _("This person looks totally defeated. Tattered clothes surround his skeletal form. If there was a fifth raider of the apocalypse, it would be him and his name would be Hard Work.");
+    character_descriptions [ PERSON_BRUCE ] = _("This person looks totally defeated. Tattered clothes surround his skeletal form. If there was a fifth rider of the apocalypse, it would be him and his name would be Hard Work.");
 
-    character_descriptions [ PERSON_SKIPPY ] = _("It seems that even during the end of the world the species known as 'Salesman' is able to survive. Just his presence makes you want to kill all humans.");
+    character_descriptions [ PERSON_SKIPPY ] = _("It seems that even at the end of the world the species known as 'Salesman' is able to survive. Just his presence makes you want to destroy all humans.");
     
     character_descriptions [ PERSON_EWALD ] = _("He looks unexplicably happy.");
 
     character_descriptions [ PERSON_STONE ] = _("In some places of the world there exists a very interesting saying. 'Tough as nails.' However, in every place where the Stone trader family stays for a while, a new saying emerges. 'Tough as the Stones.'");
 
-    character_descriptions [ PERSON_DIXON ] = _("It is very obvious that this is not a normal Red Guard. Most of them do not have oil stains on their armor and smell of alcohol.");
+    character_descriptions [ PERSON_DIXON ] = _("It is very obvious that this is not a normal Red Guard. Most of them do not have oil stains on their armor, or smell of alcohol.");
 
     character_descriptions [ PERSON_KEVINS_GUARD ] = _("It looks like a 614. It moves like a 614. It even kills like a 614. Must be a 614 then.");
 
-    character_descriptions [ PERSON_RMS ] = _("He must be the resident scientist. The only thing keeping his body alive is the massive coffee overdose that he takes early in the morning every day. The amount of cafeine that he has in his blood right now would be enough to kill ten humans, but since computer scientists are a different species, he is unharmed.");
+    character_descriptions [ PERSON_RMS ] = _("He must be the resident scientist. The only thing keeping his body alive is the massive coffee overdose that he takes early every morning. The amount of caffeine that he has in his blood right now would be enough to kill ten humans, but since computer scientists are a different species, he is unharmed.");
 
     character_descriptions [ PERSON_DARWIN ] = _("Something about him makes you think of angels. Except angels are usually sane, do not have an urge to kill everything around them and are much better at singing religious songs.");
 
@@ -164,17 +162,17 @@ init_character_descriptions ( void )
 
     character_descriptions [ PERSON_PENDRAGON ] = _("He seems to be the chief of the gate guards. Hard to say anything more, the armor hides his body.");
 
-    character_descriptions [ PERSON_BENJAMIN ] = _("Just an another Red Guard. The armor hides his body.");
+    character_descriptions [ PERSON_BENJAMIN ] = _("Yet another Red Guard, the ranged weapons instructor. The armor hides his body.");
 
     character_descriptions [ PERSON_DOC_MOORE ] = _("Some people say that every doctor is addicted to drugs. You estimate that right now this one is high on at least four different narcotics. Doc Moore seems very happy indeed...");
 
     character_descriptions [ PERSON_BUTCH ] = _("Yet another Red Guard. You cannot say anything more, the armor hides his body.");
 
-    character_descriptions [ PERSON_SPENCER ] = _("He looks taller than most of the Red Guards, but you cannot really say anything more about him, the armor hides his body.");
+    character_descriptions [ PERSON_SPENCER ] = _("He looks taller than most of the Red Guards, but you cannot really determine anything more about him, the armor hides his body.");
 
     character_descriptions [ PERSON_MICHELANGELO ] = _("And now you know who is to be blamed for the truly awful food in here. You are in a killing mood. Oh yeah. The cook must die. The cook must die. Ha. Ha. Ha.");
 
-    character_descriptions [ PERSON_SUBDIALOG_DUMMY ] = _("This is a major bug. Please report this incident to the developers. Thank you.");
+    character_descriptions [ PERSON_SUBDIALOG_DUMMY ] = _("This is a minor bug. Please report this incident to the developers. Thank you.");
 
     character_descriptions [ PERSON_STANDARD_BOT_AFTER_TAKEOVER ] = _("Blood. Stone. Cog. The Blood has made the Cog from the Stone. Now the Cog is making more Stone from the Blood. I wonder what is the next step of the cycle...");
 
@@ -186,6 +184,16 @@ init_character_descriptions ( void )
 
     character_descriptions [ PERSON_MS_FACILITY_GATE_GUARD_LEADER ] = _("The armor hides his body.");
 
+    character_descriptions [ PERSON_JASMINE ] = _("This very well could be the most attractive human you've ever seen. There is something odd about her, though...");
+
+    character_descriptions [ PERSON_TUTORIALTOM ] = _("This is Tom. He will introduce you to the game, and help you throughout this tutorial.");
+
+    character_descriptions [ PERSON_LUKAS ] = _("Keeper of the Red Guard armory.  The armor hides his body.");
+
+    character_descriptions [ PERSON_KOAN ] = _("This must be the guy Duncan told you about. At least, he's the only one around.");
+
+    character_descriptions [ PERSON_TANIA ] = _("A lonely scientist. The months she's spent trapped here seem to have taken their toll on her sanity.");
+
 }; // void init_character_descriptions ( void )
 
 /** 
@@ -269,7 +277,6 @@ char fpath[2048];
     free ( TitleSongName );
     
     SDL_SetClipRect ( Screen, NULL );
-    Me.status=BRIEFING;
     SetCurrentFont( Para_BFont );
     
     NextSubsectionStartPointer = TitleFilePointer;
@@ -279,8 +286,7 @@ char fpath[2048];
 	NextSubsectionStartPointer += strlen ( "*** START OF PURE SCROLLTEXT DATA ***\n" );
 	if ( (TerminationPointer=strstr ( NextSubsectionStartPointer, "\n*** END OF PURE SCROLLTEXT DATA ***")) == NULL)
 	{
-	    DebugPrintf (1, "\n\nvoid PlayATitleFile(...): Unterminated Subsection in Mission briefing....Terminating...");
-	    Terminate(ERR);
+		ErrorMessage(__FUNCTION__, "Unterminated Subsection in Mission briefing....Terminating...\n", PLEASE_INFORM, IS_FATAL);
 	}
 	ThisTextLength=TerminationPointer-NextSubsectionStartPointer;
 	PreparedBriefingText = MyMalloc (ThisTextLength + 10);
@@ -366,285 +372,6 @@ Get_Bullet_Data ( char* DataPointer )
     DebugPrintf (1, "\nEnd of Get_Bullet_Data ( char* DataPointer ) reached.");
 } // void Get_Bullet_Data ( char* DataPointer );
 
-/**
- * Delete all events and event triggers
- */
-static void
-clear_out_all_events_and_actions( void )
-{
-    int i;
-    
-    for ( i = 0 ; i < MAX_EVENT_TRIGGERS ; i++ )
-    {
-	AllEventTriggers[i].Influ_Must_Be_At_Level=-1;
-	AllEventTriggers[i].Influ_Must_Be_At_Point.x=-1;
-	AllEventTriggers[i].Influ_Must_Be_At_Point.y=-1;
-	
-	// Maybe the event is triggered by time
-	AllEventTriggers[i].Mission_Time_Must_Have_Passed=-1;
-	AllEventTriggers[i].Mission_Time_Must_Not_Have_Passed=-1;
-
-	AllEventTriggers[i].enabled=1;
-		
-	AllEventTriggers[i].TargetActionLabel="none";
-    }
-    for ( i = 0 ; i < MAX_TRIGGERED_ACTIONS_IN_GAME ; i++ )
-    {
-	AllTriggeredActions[i].ActionLabel="";
-	AllTriggeredActions[i].TeleportTarget.x = -1;
-	AllTriggeredActions[i].TeleportTarget.y = -1;
-	AllTriggeredActions[i].TeleportTargetLevel = -1;
-	AllTriggeredActions[i].also_execute_action_label="";
-	
-	AllTriggeredActions[i].modify_obstacle_with_label="";
-	AllTriggeredActions[i].modify_obstacle_to_type=0;
-	AllTriggeredActions[i].modify_event_trigger_with_action_label="";
-	AllTriggeredActions[i].modify_event_trigger_value=-1;
-	AllTriggeredActions[i].show_big_screen_message="";
-    }
-}; // void clear_out_all_events_and_actions( void )
-
-#define EVENT_TRIGGER_BEGIN_STRING "* New event trigger *"
-#define EVENT_TRIGGER_END_STRING "* End of trigger *"
-#define EVENT_ACTION_BEGIN_STRING "* New event action *"
-#define EVENT_ACTION_END_STRING "* End of action *"
-
-
-#define EVENT_ACTION_TELEPORT_TARGET_LABEL_STRING "Teleport to=\""
-
-#define EVENT_ACTION_MODIFY_EVENT_TRIGGER_STRING "modify_event_trigger_with_action_label=\""
-#define EVENT_ACTION_MODIFY_EVENT_TRIGGER_VALUE_STRING "modify_event_trigger_to="
-
-#define EVENT_ACTION_ALSO_EXECUTE_ACTION_LABEL "Also execute action with label=\""
-
-#define ACTION_LABEL_INDICATION_STRING "Name=\""
-
-#define EVENT_TRIGGER_DELETED_AFTER_TRIGGERING "Delete the event trigger after it has been triggered="
-#define TRIGGER_WHICH_TARGET_LABEL "Action=\""
-#define EVENT_TRIGGER_LABEL_STRING "Trigger at label=\""
-#define EVENT_TRIGGER_ENABLED_STRING "Enable this trigger by default="
-
-#define MODIFY_OBSTACLE_WITH_LABEL_STRING "modify_obstacle_with_label=\""
-#define MODIFY_OBSTACLE_TO_TYPE_STRING "modify_obstacle_to_type=\""
-
-#define SHOW_BIG_SCREEN_MESSAGE_STRING "show_big_screen_message=\""
-
-/**
- *
- *
- */
-static void
-decode_all_event_actions ( char* EventSectionPointer )
-{
-    char *EventPointer;
-    char *EndOfEvent;
-    int EventActionNumber;
-    char* TempMapLabelName;
-    char* TempText;
-    location TempLocation;
-
-    EventPointer=EventSectionPointer;
-    EventActionNumber=0;
-    while ( ( EventPointer = strstr ( EventPointer , EVENT_ACTION_BEGIN_STRING ) ) != NULL)
-	{
-	EventPointer += strlen( EVENT_ACTION_BEGIN_STRING ) + 1;
-
-	EndOfEvent = LocateStringInData ( EventPointer , EVENT_ACTION_END_STRING );
-	*EndOfEvent = 0;
-	DebugPrintf (1, "\n\nStarting to read details of this event action section\n\n");
-
-	//--------------------
-	// Now we decode the details of this event action section
-	//
-	AllTriggeredActions[ EventActionNumber].ActionLabel =
-	    ReadAndMallocStringFromData ( EventPointer , ACTION_LABEL_INDICATION_STRING , "\"" ) ;
-
-	//--------------------
-	// Now we see if maybe there was an obstacle label given, that should be used
-	// to change an obstacle later.  We take a look if that is the case at all, and
-	// if it is, we'll read in the corresponding obstacle label of course.
-	//
-	if ( CountStringOccurences ( EventPointer , MODIFY_OBSTACLE_WITH_LABEL_STRING ) )
-	    {
-	    DebugPrintf ( 1 , "\nOBSTACLE LABEL FOUND IN THIS EVENT ACTION!" );
-	    TempMapLabelName = 
-		ReadAndMallocStringFromData ( EventPointer , MODIFY_OBSTACLE_WITH_LABEL_STRING , "\"" ) ;
-	    AllTriggeredActions [ EventActionNumber ] . modify_obstacle_with_label = TempMapLabelName ;
-	    DebugPrintf ( 1 , "\nThe label reads: %s." , AllTriggeredActions [ EventActionNumber ] . modify_obstacle_with_label );
-	    //--------------------
-	    // But if such an obstacle label has been given, we also need to decode the new type that
-	    // this obstacle should be made into.  So we do it here:
-	    //
-	    AllTriggeredActions[ EventActionNumber ] . modify_obstacle_to_type =
-		ReadAndMallocStringFromData ( EventPointer , MODIFY_OBSTACLE_TO_TYPE_STRING , "\"" ) ;
-	    DebugPrintf ( 1 , "\nObstacle will be modified to state: %s." , AllTriggeredActions[ EventActionNumber ] . modify_obstacle_to_type );
-	    }
-
-	//--------------------
-	// Now we see if maybe there was a text given, that should be shown to user.
-	//
-	if ( CountStringOccurences ( EventPointer , SHOW_BIG_SCREEN_MESSAGE_STRING ) )
-	    {
-	    DebugPrintf ( 1 , "\nTEXT MESSAGE FOUND IN THIS EVENT ACTION!" );
-	    TempText = 
-		ReadAndMallocStringFromData ( EventPointer , SHOW_BIG_SCREEN_MESSAGE_STRING , "\"" ) ;
-	    AllTriggeredActions [ EventActionNumber ] . show_big_screen_message = TempText ;
-	    DebugPrintf ( 1 , "\nThe message reads: %s." , AllTriggeredActions [ EventActionNumber ] . show_big_screen_message );
-	    }
-
-	//--------------------
-	// Now we read in the teleport target position in x and y and level coordinates
-	//
-	if ( CountStringOccurences ( EventPointer , EVENT_ACTION_TELEPORT_TARGET_LABEL_STRING) )
-	    {
-	    TempMapLabelName = 
-		ReadAndMallocStringFromData ( EventPointer , EVENT_ACTION_TELEPORT_TARGET_LABEL_STRING , "\"" ) ;
-	    if ( strcmp ( TempMapLabelName , "NO_LABEL_DEFINED_YET" ) )
-		{
-		ResolveMapLabelOnShip ( TempMapLabelName , &TempLocation );
-		AllTriggeredActions [ EventActionNumber ] . TeleportTarget . x = TempLocation . x ;
-		AllTriggeredActions [ EventActionNumber ] . TeleportTarget . y = TempLocation . y ;
-		AllTriggeredActions [ EventActionNumber ] . TeleportTargetLevel = TempLocation . level ;
-		}
-	    else 
-		ErrorMessage(__FUNCTION__, "An action used NO_LABEL_DEFINED_YET map label teleport target.\n", PLEASE_INFORM, IS_FATAL);
-	    free(TempMapLabelName);
-	    }
-	else
-	    {
-	    AllTriggeredActions [ EventActionNumber ] . TeleportTarget . x = -1 ;
-	    AllTriggeredActions [ EventActionNumber ] . TeleportTarget . y = -1;
-	    }
-
-	if ( ! strstr( EventPointer, EVENT_ACTION_MODIFY_EVENT_TRIGGER_STRING ) ) //if there is no event trigger modified
-	    {
-	    AllTriggeredActions[ EventActionNumber ].modify_event_trigger_with_action_label = "";
-	    }
-	else  
-	    {
-	    AllTriggeredActions[ EventActionNumber ].modify_event_trigger_with_action_label =  	ReadAndMallocStringFromData ( EventPointer , 
-		    EVENT_ACTION_MODIFY_EVENT_TRIGGER_STRING , "\"" ) ;
-	    ReadValueFromStringWithDefault( EventPointer , EVENT_ACTION_MODIFY_EVENT_TRIGGER_VALUE_STRING , "%d" , "0",
-		    &AllTriggeredActions[ EventActionNumber ].modify_event_trigger_value , EndOfEvent );
-
-	    }
-
-	if ( ! strstr( EventPointer, EVENT_ACTION_ALSO_EXECUTE_ACTION_LABEL ) ) //if there is no linked action
-	    {
-	    AllTriggeredActions[ EventActionNumber ].also_execute_action_label = "";
-	    }
-	else
-	    {
-	    AllTriggeredActions[ EventActionNumber ].also_execute_action_label = ReadAndMallocStringFromData ( EventPointer , 
-		    EVENT_ACTION_ALSO_EXECUTE_ACTION_LABEL , "\"" ) ;
-	    }
-
-	EventActionNumber++;
-	*EndOfEvent = EVENT_ACTION_END_STRING[0];
-	} // While Event action begin string found...
-
-
-    DebugPrintf (1, "\nThat must have been the last Event Action section.\nWe can now start with the Triggers. Good.");  
-
-}; // void decode_all_event_actions ( char* EventSectionPointer )
-
-/** 
- *
- *
- */
-static void
-decode_all_event_triggers ( char* EventSectionPointer )
-{
-    char *EventPointer;
-    char *EndOfEvent;
-    int EventTriggerNumber;
-    char* TempMapLabelName;
-    location TempLocation;
-    char s;
-
-    EventPointer=EventSectionPointer;
-    EventTriggerNumber=0;
-    while ( ( EventPointer = strstr ( EventPointer , EVENT_TRIGGER_BEGIN_STRING ) ) != NULL)
-    {
-	EventPointer += strlen( EVENT_TRIGGER_BEGIN_STRING ) + 1;
-	
-	EndOfEvent = LocateStringInData ( EventPointer , EVENT_TRIGGER_END_STRING );
-	s = EndOfEvent[strlen(EVENT_TRIGGER_END_STRING)-1];
-        EndOfEvent[strlen(EVENT_TRIGGER_END_STRING)-1]	= 0;
-
-	DebugPrintf ( 1 , "\nStarting to read details of this event trigger section\n\n");
-	
-	//--------------------
-	// Now we decode the details of this event trigger section
-	//
-	
-	// Now we read in the triggering position in x and y and z coordinates
-	TempMapLabelName = 
-	    ReadAndMallocStringFromData ( EventPointer , EVENT_TRIGGER_LABEL_STRING , "\"" ) ;
-	    ResolveMapLabelOnShip ( TempMapLabelName , &TempLocation );
-	    AllEventTriggers [ EventTriggerNumber ] . Influ_Must_Be_At_Point . x = TempLocation . x ;
-	    AllEventTriggers [ EventTriggerNumber ] . Influ_Must_Be_At_Point . y = TempLocation . y ;
-	    AllEventTriggers[ EventTriggerNumber ] . Influ_Must_Be_At_Level = TempLocation . level ;
-
-	free ( TempMapLabelName );	
-	
-	ReadValueFromStringWithDefault( EventPointer , EVENT_TRIGGER_DELETED_AFTER_TRIGGERING , "%d" , "0",
-			     &AllEventTriggers[ EventTriggerNumber ].DeleteTriggerAfterExecution , EndOfEvent );
-	
-	AllEventTriggers[ EventTriggerNumber ].TargetActionLabel = 
-	    ReadAndMallocStringFromData ( EventPointer , TRIGGER_WHICH_TARGET_LABEL , "\"" ) ;
-
-	ReadValueFromStringWithDefault( EventPointer , EVENT_TRIGGER_ENABLED_STRING , "%d" , "1",
-			     &AllEventTriggers[ EventTriggerNumber ].enabled , EndOfEvent );
-	
-	EventTriggerNumber++;
-	        EndOfEvent[strlen(EVENT_TRIGGER_END_STRING)-1] = '\0';
-
-	EndOfEvent[strlen(EVENT_TRIGGER_END_STRING)-1] = s;
-    } // While Event trigger begin string found...
-    
-
-}; // void decode_all_event_triggers ( char* EventSectionPointer )
-
-/**
- * This function reads in the game events, i.e. the locations and conditions
- * under which some actions are triggered.
- */
-void 
-GetEventsAndEventTriggers ( const char* EventsAndEventTriggersFilename )
-{
-  char* EventSectionPointer;
-char fpath[2048];
-
-  //--------------------
-  // At first we clear out any garbage that might randomly reside in the current event
-  // and action structures...
-  //
-  clear_out_all_events_and_actions();
-
-  //--------------------
-  // Now its time to start loading the event file...
-  //
-  find_file (EventsAndEventTriggersFilename , MAP_DIR , fpath, 0 );
-  EventSectionPointer = 
-    ReadAndMallocAndTerminateFile( fpath , 
-				   "*** END OF EVENT ACTION AND EVENT TRIGGER FILE *** LEAVE THIS TERMINATOR IN HERE ***" 
-				   ) ;
-
-  //--------------------
-  // At first we decode ALL THE EVENT ACTIONS not the TRIGGERS!!!!
-  //
-  decode_all_event_actions ( EventSectionPointer );
-
-  //--------------------
-  // Now we decode ALL THE EVENT TRIGGERS not the ACTIONS!!!!
-  //
-  decode_all_event_triggers ( EventSectionPointer );
-
-  free ( EventSectionPointer ) ;
-}; // void Get_Game_Events ( char* EventSectionPointer );
-
-
 /**
  * This function reads the descriptions of the different programs
  * (source and blobs) that are used for magic
@@ -724,9 +451,9 @@ There are more skills defined, than the maximum number specified in the code!",
 		& ProgramToFill -> heat_cost  , EndOfProgramData );
 	ReadValueFromStringWithDefault( ProgramPointer , "Cost per level=" , "%hd" , "0",
 		& ProgramToFill -> heat_cost_per_level  , EndOfProgramData );
-	ReadValueFromStringWithDefault( ProgramPointer , "Present at startup=" , "%hhd" , "0",
+	ReadValueFromStringWithDefault( ProgramPointer , "Present at startup=" , "%hd" , "0",
 		& ProgramToFill -> present_at_startup  , EndOfProgramData );
-	ReadValueFromStringWithDefault( ProgramPointer , "Artwork internal code=" , "%hhd" , "-1",
+	ReadValueFromStringWithDefault( ProgramPointer , "Artwork internal code=" , "%d" , "-1",
 		& ProgramToFill -> graphics_code  , EndOfProgramData );
 	ReadValueFromStringWithDefault( ProgramPointer, "Effect duration=", "%f", "0",
 		& ProgramToFill -> effect_duration, EndOfProgramData );
@@ -761,14 +488,14 @@ Get_Robot_Data ( void* DataPointer )
   double maxenergy_calibrator;
   float energyloss_calibrator;
   double experience_reward_calibrator;
-  double range_of_vision_calibrator;
+  double aggression_distance_calibrator;
 
 #define MAXSPEED_CALIBRATOR_STRING "Common factor for all droids maxspeed values: "
 #define ACCELERATION_CALIBRATOR_STRING "Common factor for all droids acceleration values: "
 #define MAXENERGY_CALIBRATOR_STRING "Common factor for all droids maximum energy values: "
 #define ENERGYLOSS_CALIBRATOR_STRING "Common factor for all droids energyloss values: "
 #define EXPERIENCE_REWARD_CALIBRATOR_STRING "Common factor for all droids experience_reward values: "
-#define RANGE_OF_VISION_CALIBRATOR_STRING "Common factor for all droids range of vision: "
+#define AGGRESSION_DISTANCE_CALIBRATOR_STRING "Common factor for all droids aggression distance: "
 
 #define ROBOT_SECTION_BEGIN_STRING "*** Start of Robot Data Section: ***" 
 #define ROBOT_SECTION_END_STRING "*** End of Robot Data Section: ***" 
@@ -834,8 +561,8 @@ Get_Robot_Data ( void* DataPointer )
 		       &experience_reward_calibrator , EndOfDataPointer );
 
   // Now we read in the range of vision calibration factor for all droids
-  ReadValueFromString( RobotPointer , RANGE_OF_VISION_CALIBRATOR_STRING , "%lf" , 
-		       &range_of_vision_calibrator , EndOfDataPointer );
+  ReadValueFromString( RobotPointer , AGGRESSION_DISTANCE_CALIBRATOR_STRING , "%lf" , 
+		       &aggression_distance_calibrator , EndOfDataPointer );
 
   DebugPrintf ( 1 , "\n\nStarting to read Robot data...\n\n" );
   //--------------------
@@ -912,8 +639,8 @@ Get_Robot_Data ( void* DataPointer )
 			   &Druidmap[RobotIndex].lose_health , EndOfDataPointer );
 
       // Now we read in range of vision of this droid
-      ReadValueFromString( RobotPointer , "Range of vision of this droid=" , "%f" , 
-			   &Druidmap[RobotIndex].range_of_vision , EndOfDataPointer );
+      ReadValueFromString( RobotPointer , "Aggression distance of this droid=" , "%f" , 
+			   &Druidmap[RobotIndex].aggression_distance , EndOfDataPointer );
 
       // Now we read in range of vision of this droid
       ReadValueFromString( RobotPointer , "Time spent eyeing Tux=" , "%f" , 
@@ -975,10 +702,6 @@ Get_Robot_Data ( void* DataPointer )
       ReadValueFromString( RobotPointer , TO_HIT_STRING , "%hd" , 
 			   &Druidmap[RobotIndex].to_hit , EndOfDataPointer );
 
-      // Now we read in the modifier, that increases/decreases the chance of this robot getting hit
-      ReadValueFromString( RobotPointer , GETTING_HIT_MODIFIER_STRING , "%hd" , 
-			   &Druidmap[RobotIndex].getting_hit_modifier , EndOfDataPointer );
-
       // Now we read in the modifier, that increases/decreases the chance of this robot getting hit
       ReadValueFromString( RobotPointer , "Time to recover after getting hit=" , "%f" , 
 			   &Druidmap[RobotIndex] . recover_time_after_getting_hit , EndOfDataPointer );
@@ -1008,7 +731,7 @@ Get_Robot_Data ( void* DataPointer )
       Druidmap [ i ] . maxspeed *= maxspeed_calibrator;
       Druidmap [ i ] . maxenergy *= maxenergy_calibrator;
       Druidmap [ i ] . experience_reward *= experience_reward_calibrator;
-      Druidmap [ i ] . range_of_vision *= range_of_vision_calibrator;
+      Druidmap [ i ] . aggression_distance *= aggression_distance_calibrator;
       Druidmap [ i ] . lose_health *= energyloss_calibrator;
       Druidmap [ i ] . weapon_item . currently_held_in_hand = FALSE ;
     }
@@ -1556,27 +1279,46 @@ char fpath[2048];
 
 char copyright[] = "\nCopyright (C) 2004 Johannes Prix, Reinhard Prix\n\
 Copyright (C) 2005-2007 Arthur Huillet, Karol Swietlicki\n\
-Freedroid comes with NO WARRANTY to the extent permitted by law.\n\
-You may redistribute copies of Freedroid\n\
+FreedroidRPG comes with NO WARRANTY to the extent permitted by law.\n\
+You may redistribute copies of FreedroidRPG\n\
 under the terms of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n";
 
 
 char usage_string[] ="\
-Usage: freedroid [-v|--version] \n\
-                 [-s|--sound] [-q|--nosound] \n\
-                 [-o|--open_gl] [-n|--no_open_gl]\n\
-                 [-f|--fullscreen] [-w|--window]\n\
-                 [-m|--mapcheck] \n\
-                 [-d|--debug=LEVEL]\n\
-		 [-r|--resolution=CODE]\n\
+Usage: freedroidRPG [-h | --help] \n\
+                    [-v | --version] \n\
+                    [-s | --sound] [-q | --nosound] \n\
+                    [-o | --open_gl] [-n | --no_open_gl] \n\
+                    [-f | --fullscreen] [-w | --window] \n\
+                    [-d X | --debug=X]       X = 0-5; default 1 \n\
+                    [-r Y | --resolution=Y]  Y = 99 lists available resolutions. \n\
 \n\
-Please report bugs either by entering them into the bug-tracking\n\
-system on our sourceforge-website via this link:\n\n\
+Please report bugs either by entering them into the bug tracker\n\
+on our sourceforge-website at:\n\n\
 http://sourceforge.net/projects/freedroid/\n\n\
-or EVEN BETTER, report them by sending e-mail to:\n\n\
+or by sending an e-mail to:\n\n\
 freedroid-discussion@lists.sourceforge.net\n\n\
-Thanks a lot in advance, the Freedroid dev team.\n\n";
+For more information and know issues please see README.\n\
+Thanks a lot in advance.\n\
+                          / The FreedroidRPG dev team.\n\n";
+
+screen_resolution screen_resolutions[] = {
+		// xres,yres, cmdline comment, display in menu
+		{  640,  480, "640 x 480 (default with SDL)",    TRUE  },
+		{  800,  600, "800 x 600 (default with OpenGL)", TRUE  },
+		{ 1024,  768, "1024 x 768",                      TRUE  },
+		{ 1152,  864, "1152 x 864",                      TRUE  },
+		{ 1280,  960, "1280 x 960",                      TRUE  },
+		{ 1400, 1050, "1400 x 1050",                     TRUE  },
+		{ 1280, 1024, "Unsupported! (1280 x 1024)",      FALSE },
+		{ 1024,  600, "Unsupported! (1024 x 600)",       FALSE },
+		{ 1280,  800, "Unsupported! (1280 x 800)",       FALSE },
+		{ 1440,  900, "Unsupported! (1440 x 900)",       FALSE },
+		{ 1680, 1050, "Unsupported! (1680 x 1050)",      FALSE },
+		// end of list
+		{   -1,   -1, "",                                FALSE }
+};
 
 /* -----------------------------------------------------------------
  *  parse command line arguments and set global switches 
@@ -1598,7 +1340,6 @@ ParseCommandLine (int argc, char *const argv[])
 	{"debug",       1, 0,  'd'},
 	{"window",      0, 0,  'w'},
 	{"fullscreen",  0, 0,  'f'},
-	{"mapcheck",    0, 0,  'm'},
 	{"resolution",  1, 0,  'r'},	
 	{ 0,            0, 0,    0}
     };
@@ -1607,7 +1348,7 @@ ParseCommandLine (int argc, char *const argv[])
 
     while ( 1 )
     {
-	c = getopt_long ( argc , argv , "vonqst:h?d::r:wfm" , long_options , NULL );
+	c = getopt_long ( argc , argv , "vonqst:h?d::r:wf" , long_options , NULL );
 	if ( c == -1 )
 	    break;
 
@@ -1658,81 +1399,37 @@ ParseCommandLine (int argc, char *const argv[])
 		}
 		else
 		{
+		    int nb_res = 0;
+		    while ( screen_resolutions[nb_res].xres != -1 ) ++nb_res;
+
 		    resolution_code = atoi (optarg);
-		    switch ( resolution_code )
+		    if ( resolution_code >= 0 && resolution_code < nb_res )
 		    {
-			case 0:
-			    command_line_override_for_screen_resolution = TRUE ;
-			    GameConfig . screen_width = 640 ; 
-			    GameConfig . screen_height = 480 ;
-			    DebugPrintf ( 1 , "\n%s(): Command line argument -r 0 recognized." , __FUNCTION__ );
-			    break;
-			case 1:
-			    command_line_override_for_screen_resolution = TRUE ;
-			    GameConfig . screen_width = 800 ; 
-			    GameConfig . screen_height = 600 ;
-			    DebugPrintf ( 1 , "\n%s(): Command line argument -r 1 recognized." , __FUNCTION__ );
-			    break;
-			case 2:
-			    command_line_override_for_screen_resolution = TRUE ;
-			    GameConfig . screen_width = 1024 ; 
-			    GameConfig . screen_height = 768 ;
-			    DebugPrintf ( 1 , "\n%s(): Command line argument -r 2 recognized." , __FUNCTION__ );
-			    break;
-			case 3:
-			    command_line_override_for_screen_resolution = TRUE ;
-			    GameConfig . screen_width = 1152 ; 
-			    GameConfig . screen_height = 864 ;
-			    DebugPrintf ( 1 , "\n%s(): Command line argument -r 3 recognized." , __FUNCTION__ );
-			    break;
-			case 4:
-	                    command_line_override_for_screen_resolution = TRUE ;
-                            GameConfig . screen_width = 1280 ;
-                            GameConfig . screen_height = 960 ;
-                            DebugPrintf ( 1 , "\n%s(): Command line argument -r 4 recognized." , __FUNCTION__ );
-                            break;
-			case 5:
-                            command_line_override_for_screen_resolution = TRUE ;
-                            GameConfig . screen_width = 1280 ;
-                            GameConfig . screen_height =1024 ;
-                            DebugPrintf ( 1 , "\n%s(): Command line argument -r 5 recognized." , __FUNCTION__ );
-                            break;
-			case 6:
-                            command_line_override_for_screen_resolution = TRUE ;
-                            GameConfig . screen_width = 1280 ;
-                            GameConfig . screen_height = 800 ;
-                            DebugPrintf ( 1 , "\n%s(): Command line argument -r 6 recognized." , __FUNCTION__ );
-                            break;
-			case 7:
-                            command_line_override_for_screen_resolution = TRUE ;
-                            GameConfig . screen_width = 1440 ;
-                            GameConfig . screen_height =900 ;
-                            DebugPrintf ( 1 , "\n%s(): Command line argument -r 7 recognized." , __FUNCTION__ );
-                            break;
-			case 8:
-                            command_line_override_for_screen_resolution = TRUE ;
-                            GameConfig . screen_width = 1680 ;
-                            GameConfig . screen_height =1050 ;
-                            DebugPrintf ( 1 , "\n%s(): Command line argument -r 8 recognized." , __FUNCTION__ );
-                            break;
-			default:
-			    fprintf( stderr, "\nresolution code received: %d" , resolution_code );
-			    ErrorMessage ( __FUNCTION__  , "\
-The resolution identifier given is not a valid resolution code.\n\
-These codes correspond to the following resolutions available:\n\
-     0 = 640 x 480 (default with SDL)\n\
-     1 = 800 x 600 (default with OpenGL)\n\
-     2 = 1024 x 768 \n\
-     3 = 1152 x 864 \n\
-     4 = 1280 x 960 \n\
-     5 = Unsupported! (1280 x 1024) \n\
-     6 = Unsupported! (1280 x 800) \n\
-     7 = Unsupported! (1440 x 900) \n\
-     8 = Unsupported! (1680 x 1050) \n\
-Anything else will not be accepted right now, but you can send in\n\
-your suggestion to the FreedroidRPG dev team to enable new resolutions.",
-						       NO_NEED_TO_INFORM , IS_FATAL );
-			    break;
+			    if (resolution_code != 0) command_line_override_for_screen_resolution = TRUE;
+			    GameConfig.screen_width  = screen_resolutions[resolution_code].xres;
+			    GameConfig.screen_height = screen_resolutions[resolution_code].yres;
+				DebugPrintf ( 1 , "\n%s(): Command line argument -r %d recognized." , __FUNCTION__, resolution_code );
+		    }
+		    else 
+		    {
+		    	fprintf( stderr, "\nresolution code received: %d" , resolution_code );
+		    	char* txt = (char*)malloc( (nb_res*128 + 1) * sizeof(char) );
+		    	txt[0] = '\0';
+		    	int i;
+		    	for (i=0; i<nb_res; ++i)
+		    	{
+		    		char tmp[129];
+	    			snprintf(tmp, 129, "\t\t%d = %s\n", i, screen_resolutions[i].comment);
+		    		strncat(txt, tmp, 128);
+		    	}
+		    	ErrorMessage ( __FUNCTION__, "  %s%s  %s", NO_NEED_TO_INFORM, IS_FATAL,
+		    	               "\tThe resolution identifier given is not a valid resolution code.\n"
+		    	               "\tThese codes correspond to the following resolutions available:\n",
+		    	               txt,
+		    	               "\tAnything else will not be accepted right now, but you can send in\n"
+		    	               "\tyour suggestion to the FreedroidRPG dev team to enable new resolutions.\n"
+		    			     );
+		    	free(txt);
 		    }
 		}
 		break;
@@ -1745,10 +1442,6 @@ your suggestion to the FreedroidRPG dev team to enable new resolutions.",
 		GameConfig . fullscreen_on = FALSE;
 		break;
 		
-	    case 'm':
-		skip_initial_menus = TRUE;
-		break;
-		
 	    default:
 		printf ("\nOption %c not implemented yet! Ignored.", c);
 		break;
@@ -1837,7 +1530,6 @@ InitHarmlessTuxStatusVariables( )
     Me . max_temperature = 10 ;
     Me . health_recovery_rate = 0.2;
     Me . cooling_rate = 0.2;
-    Me . status = MOBILE;
     Me . phase = 0;
     Me . MissionTimeElapsed=0;
     Me . Current_Victim_Resistance_Factor=1;
@@ -1867,13 +1559,12 @@ InitHarmlessTuxStatusVariables( )
  * whenever or better before any new game is started.
  * -----------------------------------------------------------------*/
 void
-PrepareStartOfNewCharacter ( void )
+PrepareStartOfNewCharacter ( char * startpos )
 {
     int i , j ;
     int StartingLevel=0;
     int StartingXPos=0;
     int StartingYPos=0;
-    int MissionTargetIndex = 0;
     location StartPosition;
     
     Activate_Conservative_Frame_Computation();
@@ -1906,7 +1597,7 @@ PrepareStartOfNewCharacter ( void )
     // Now the mission file is read into memory.  That means we can start to decode the details given
     // in the body of the mission file.  
     //
-    GetEventsAndEventTriggers ( "freedroid.events" );
+    GetEventTriggers ( "freedroid.events" );
     
     if ( !skip_initial_menus )
 	PlayATitleFile ( "StartOfGame.title" );
@@ -1920,7 +1611,7 @@ PrepareStartOfNewCharacter ( void )
     
     GetCrew ( "ReturnOfTux.droids" ) ;
     
-    ResolveMapLabelOnShip ( "NewTuxStartGameSquare" , &StartPosition );
+    ResolveMapLabelOnShip ( startpos , &StartPosition );
     Teleport( StartPosition . level, StartPosition . x, StartPosition . y, FALSE);
     
     Me . teleport_anchor . x = 0 ; //no anchor at the beginning
@@ -1999,22 +1690,11 @@ PrepareStartOfNewCharacter ( void )
     DebugPrintf ( 1 , "\n%s():  Shuffling droids on all %d levels!" , __FUNCTION__ , curShip.num_levels );
     for ( i = 0 ; i < curShip.num_levels ; i ++ )
     {
-	ShuffleEnemys( i );
+    	if ( curShip.AllLevels[i] == NULL ) continue;
+    	ShuffleEnemys( i );
     }
     
     
-    //--------------------
-    // Now we start those missions, that are to be assigned automatically to the
-    // player at game start
-    //
-    for ( MissionTargetIndex = 0 ; MissionTargetIndex < MAX_MISSIONS_IN_GAME ; MissionTargetIndex ++ )
-    {
-	if ( Me.AllMissions[ MissionTargetIndex ].AutomaticallyAssignThisMissionAtGameStart ) 
-	{
-	    AssignMission( MissionTargetIndex );
-	}
-    }
-    
     Me . mouse_move_target . x = ( -1 ) ;
     Me . mouse_move_target . y = ( -1 ) ;
     Me . mouse_move_target . z = ( -1 ) ;
@@ -2066,7 +1746,6 @@ ResetGameConfigToDefaultValues ( void )
     GameConfig . hog_CPU = FALSE ;
     GameConfig . highlighting_mode_full = TRUE ;
     GameConfig . skip_light_radius = FALSE ; 
-    GameConfig . omit_tux_in_level_editor = TRUE ;
     GameConfig . omit_obstacles_in_level_editor = FALSE ;
     GameConfig . omit_enemies_in_level_editor = TRUE ;
     GameConfig . zoom_is_on = FALSE ;
@@ -2142,7 +1821,7 @@ InitFreedroid ( int argc, char ** argv )
     //
     if ( strstr ( VERSION , "svn" ) != NULL )
     {
-	DebugPrintf ( -4 , "\nThis seems to be a cvs version, so we'll exit on floating point exceptions." );
+	DebugPrintf ( -4 , "\nThis seems to be a development version, so we'll exit on floating point exceptions." );
 	// feenableexcept ( FE_ALL_EXCEPT );
 	// feenableexcept ( FE_INEXACT ) ;
 	// feenableexcept ( FE_UNDERFLOW ) ;
@@ -2198,8 +1877,6 @@ InitFreedroid ( int argc, char ** argv )
     //
     implant_backtrace_into_signal_handlers ( ) ;
     
-    GameConfig . level_editor_edit_mode = LEVEL_EDITOR_SELECTION_FLOOR ;
-
     init_character_descriptions ( );
     
     clear_out_arrays_for_fresh_game ();
@@ -2234,7 +1911,7 @@ I will try to use local directory instead\n");
     {
 	DebugPrintf ( 0 , "\n----------------------------------------------------------------------\n\
 You seem not to have the directory %s in your home directory.\n\
-This directory is used by freedroid to store saved games and your personal settings.\n\
+This directory is used by FreedroidRPG to store saved games and your personal settings.\n\
 So I'll try to create it now...\n\
 ----------------------------------------------------------------------\n", our_config_dir );
 #if __WIN32__
@@ -2282,6 +1959,8 @@ I will not be able to load or save games or configurations\n\
     InitVideo ();
     
     init_keyboard_input_array();
+    init_lua();
+
     ShowStartupPercentage ( 2 ) ; 
     
     InitAudio ();
@@ -2299,11 +1978,6 @@ I will not be able to load or save games or configurations\n\
     
     ShowStartupPercentage ( 10 ) ; 
     
-    //--------------------
-    // Now we prepare the automap data for later use
-    //
-    GameConfig . Automap_Visible = TRUE;
-    
     ShowStartupPercentage ( 14 ) ; 
     
     Init_Game_Data(); 
@@ -2320,8 +1994,6 @@ I will not be able to load or save games or configurations\n\
  
     ShowStartupPercentage ( 100 ) ; 
 
-    if(GameConfig . screen_width == 640)
-	 GiveMouseAlertWindow ( _("\nYou are playing in 640x480.\n\nWhile this resolution works correctly and will\ngive you a great gaming experience, its support is\nin the process of being dropped, therefore you will\nwant to consider using 800x600 or 1024x768.\n\nThank you.\n"));
     if ( strstr( VERSION, "rc" ) )
 	 GiveMouseAlertWindow ( _("\nYou are playing a candidate release.\nMany strange bugs might still be present in the game.\nPlease report anything you may find to #freedroid at irc.freenode.net, or\n by mail to freedroid-discussion at lists.sourceforge.net\nThank you for helping us test the game.\nGood luck!\n"));
 
@@ -2342,7 +2014,6 @@ ThouArtDefeated (void)
     int now;
 
     DebugPrintf ( 1 , "\n%s(): Real function call confirmed." , __FUNCTION__ );
-    Me . status = INFOUT ;
     append_new_game_message ( _("Game over.\n") );
     GameConfig . Inventory_Visible = FALSE;
     GameConfig . CharacterScreen_Visible = FALSE;
@@ -2430,7 +2101,6 @@ ThouHastWon (void)
     int now;
 
     DebugPrintf ( 1 , "\n%s(): Real function call confirmed." , __FUNCTION__ );
-    Me . status = INFOUT ;
     append_new_game_message ( _("Game won.\n") );
     GameConfig . Inventory_Visible = FALSE;
     GameConfig . CharacterScreen_Visible = FALSE;
