@@ -29,7 +29,12 @@
 #include "global.h"
 #include "proto.h"
 
-extern void LevelEditor(void);
+#include "lvledit/lvledit.h"
+#include "lvledit/lvledit_actions.h"
+#include "lvledit/lvledit_grass_actions.h"
+#include "lvledit/lvledit_tools.h"
+#include "lvledit/lvledit_widgets.h"
+
 
 #define KEY_PRESS    ( 1.) /**< Key is pressed. */
 #define KEY_RELEASE  (-1.) /**< Key is released. */
@@ -37,7 +42,7 @@ extern void LevelEditor(void);
 /* name of each keybinding */
 const char *keybindNames[] = {
     /* General */
-    "fullscreen", "keychart", "quit", "wall_transparency", 
+    "keychart", "fullscreen", "quit", "wall_transparency", 
 
     /* Ingame */
     "inventory", "skill", "character", "quests",
@@ -59,8 +64,10 @@ const char *keybindNames[] = {
     "place_obstacle_kp7", "place_obstacle_kp8", "place_obstacle_kp9",
     "change_map_label", "zoom_out",
     "cycle_marked_obstacle",
+    "cut", "copy", "paste",
     "next_tab", "undo", "redo", "beautify_grass",
     "connect_waypoint",
+    "toolbar_scroll_left", "toolbar_scroll_right", "toolbar_step_left", "toolbar_step_right",
 
     /* Cheat keys */
     "cheat_xp+_1k", "cheat_xp*_2",
@@ -126,7 +133,7 @@ void input_set_keybind( char *keybind, SDLKey key, SDLMod mod)
 	    GameConfig.input_keybinds[i].mod = mod;
 	    return;
 	}
-    ErrorMessage(__FUNCTION__, "Unable to set keybinding '%s', that command doesn't exist.\n", PLEASE_INFORM, IS_FATAL, keybind);
+    ErrorMessage(__FUNCTION__, "Unable to set keybinding '%s', that command doesn't exist.\n", NO_NEED_TO_INFORM, IS_WARNING_ONLY, keybind);
 }
 
 void input_get_keybind(char *cmdname, SDLKey *key, SDLMod *mod)
@@ -151,8 +158,15 @@ void input_get_keybind(char *cmdname, SDLKey *key, SDLMod *mod)
  */
 void input_set_default (void)
 {
-    input_set_keybind("fullscreen", SDLK_F2, KMOD_NONE);
+    /*
+    If changing defaults, please make sure to update relevant parts in
+    README 
+    map/titles/StartOfGame.title
+    map/titles/level_editor_help.title
+    */
+
     input_set_keybind("keychart", SDLK_F1, KMOD_NONE);
+    input_set_keybind("fullscreen", SDLK_F2, KMOD_NONE);
     input_set_keybind("quit", SDLK_q, KMOD_LCTRL);
     input_set_keybind("wall_transparency", SDLK_t, KMOD_NONE);
 
@@ -204,14 +218,21 @@ void input_set_default (void)
     input_set_keybind("place_obstacle_kp8", SDLK_KP8, KMOD_NONE);
     input_set_keybind("place_obstacle_kp9", SDLK_KP9, KMOD_NONE);
     input_set_keybind("place_obstacle_kp9", SDLK_KP9, KMOD_NONE);
-    input_set_keybind("change_map_label", SDLK_l, KMOD_NONE);
+    input_set_keybind("change_map_label", SDLK_m, KMOD_NONE);
     input_set_keybind("zoom_out", SDLK_o, KMOD_NONE);
     input_set_keybind("cycle_marked_obstacle", SDLK_n, KMOD_NONE);
     input_set_keybind("next_tab", SDLK_f, KMOD_NONE);
-    input_set_keybind("undo", SDLK_u, KMOD_NONE);
-    input_set_keybind("redo", SDLK_r, KMOD_NONE);
+    input_set_keybind("undo", SDLK_z, KMOD_NONE);
+    input_set_keybind("redo", SDLK_y, KMOD_NONE);
     input_set_keybind("beautify_grass", SDLK_b, KMOD_LCTRL);
     input_set_keybind("connect_waypoint", SDLK_c, KMOD_NONE);
+    input_set_keybind("toolbar_scroll_left", SDLK_PAGEUP, KMOD_NONE);
+    input_set_keybind("toolbar_scroll_right", SDLK_PAGEDOWN, KMOD_NONE);
+    input_set_keybind("toolbar_step_left", SDLK_PAGEUP, KMOD_LCTRL);
+    input_set_keybind("toolbar_step_right", SDLK_PAGEDOWN, KMOD_LCTRL);
+    input_set_keybind("cut", SDLK_x, KMOD_LCTRL);
+    input_set_keybind("copy", SDLK_c, KMOD_LCTRL);
+    input_set_keybind("paste", SDLK_v, KMOD_LCTRL);
 
     /* Cheat */
     input_set_keybind("cheat_xp+_1k", SDLK_KP1, KMOD_NONE);
@@ -324,6 +345,8 @@ void keychart()
     const int maxcmds = sizeof(keybindNames)/sizeof(keybindNames[0]) - 2;
     int per_page = get_nb_commands_per_page();
 
+    Activate_Conservative_Frame_Computation();
+
     SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
     while (!done) {
 	while (SDL_PollEvent(&event)) {
@@ -376,10 +399,28 @@ void keychart()
 		}
 		if (event.key.keysym.sym == SDLK_RETURN) {
 		    int newmod;
+		    int oldkey, oldmod;
+		    int i;
 		    display_keychart(startpos, cursor, TRUE);
+		    oldkey = GameConfig.input_keybinds[cursor].key;
+		    oldmod = GameConfig.input_keybinds[cursor].mod;
+
 		    GameConfig.input_keybinds[cursor].key = getchar_raw(&newmod);
 		    newmod &= ~(KMOD_CAPS | KMOD_NUM | KMOD_MODE); /* We want to ignore "global" modifiers. */
 		    GameConfig.input_keybinds[cursor].mod = newmod;
+
+		    for (i=0; strcmp(keybindNames[i], "end"); i++) {
+			if (i == cursor) 
+			    continue;
+
+			if (GameConfig.input_keybinds[i].key == GameConfig.input_keybinds[cursor].key && GameConfig.input_keybinds[i].mod == newmod) {
+			    /* If the key we have just assigned was already assigned to another command... */
+			    GameConfig.input_keybinds[i].key = oldkey;
+			    GameConfig.input_keybinds[i].mod = oldmod;
+			    /* ... swap the keys (assign the old key to the conflicting command)*/
+			}
+		    }
+
 		}
 	    }
 	}
@@ -394,7 +435,6 @@ void keychart()
  *
  *    @param keynum The index of the  keybind.
  *    @param value The value of the keypress (defined above).
- *    @param abs Whether or not it's an absolute value (for them joystick).
  */
 #define KEYPRESS(s)    ((strcmp(GameConfig.input_keybinds[keynum].name,s)==0) && value==KEY_PRESS)
 #define INGAME()	(game_status == INSIDE_GAME)
@@ -490,9 +530,6 @@ static int input_key( int keynum, int value)
 	} else if (KEYPRESS("automap")) {
 	    toggle_automap();
 	    return 0;
-	} else if (KEYPRESS("keychart")) {
-	    keychart();
-	    return 0;
 	} else if (KEYPRESS("cheat_level_editor")) {
 	    LevelEditor();
 	    return 0;
@@ -527,7 +564,7 @@ static int input_key( int keynum, int value)
 	    ItemDropFromLevelEditor();
 	    return 0;
 	} else if (KEYPRESS("change_map_label")) {
-	    level_editor_action_change_map_label_user();
+	    level_editor_action_change_map_label_user(CURLEVEL());
 	    return 0;
 	} else if (KEYPRESS("zoom_out")) {
 	    GameConfig . zoom_is_on = !GameConfig . zoom_is_on ;
@@ -536,7 +573,7 @@ static int input_key( int keynum, int value)
 	    level_editor_cycle_marked_obstacle();
 	    return 0;
 	} else if (KEYPRESS("next_tab")) {
-	    level_editor_next_tab();
+	    GiveMouseAlertWindow("Reimplement that");
 	    return 0;
 	} else if (KEYPRESS("undo")) {
 	    level_editor_action_undo();
@@ -545,7 +582,19 @@ static int input_key( int keynum, int value)
 	    level_editor_action_redo();
 	    return 0;
 	} else if (KEYPRESS("beautify_grass")) {
-	    level_editor_beautify_grass_tiles();
+	    level_editor_beautify_grass_tiles(EditLevel());
+	    return 0;
+	} else if (KEYPRESS("toolbar_scroll_left")) {
+	    leveleditor_toolbar_scroll_left();
+	    return 0;
+	} else if (KEYPRESS("toolbar_scroll_right")) {
+	    leveleditor_toolbar_scroll_right();
+	    return 0;
+	} else if (KEYPRESS("toolbar_step_left")) {
+	    leveleditor_toolbar_left();
+	    return 0;
+	} else if (KEYPRESS("toolbar_step_right")) {
+	    leveleditor_toolbar_right();
 	    return 0;
 	} else if (!strncmp(GameConfig.input_keybinds[keynum].name, "place_obstacle_kp", strlen("place_obstacle_kp")) && value==KEY_PRESS) {
 	    int number = atoi(GameConfig.input_keybinds[keynum].name + strlen("place_obstacle_kp"));
@@ -556,7 +605,16 @@ static int input_key( int keynum, int value)
 	    level_editor_place_aligned_obstacle(number);
 	    return 0;
 	} else if (KEYPRESS("connect_waypoint")) {
-	    level_editor_action_toggle_waypoint_connection_user();
+	    level_editor_action_toggle_waypoint_connection_user(CURLEVEL(), EditX(), EditY());
+	    return 0;
+	} else if (KEYPRESS("cut")) {
+	    level_editor_cut_selection();
+	    return 0;
+	} else if (KEYPRESS("copy")) {
+	    level_editor_copy_selection();
+	    return 0;
+	} else if (KEYPRESS("paste")) {
+	    level_editor_paste_selection();
 	    return 0;
 	}
     }
@@ -572,6 +630,9 @@ static int input_key( int keynum, int value)
     } else if (KEYPRESS("wall_transparency")) {
 	    GameConfig.transparency = ! GameConfig.transparency;
 	    return 0;
+    } else if (KEYPRESS("keychart")) {
+	keychart();
+	return 0;
     } else if (KEYPRESS("quit")) {
 	Terminate(0);
 	return 0;
@@ -583,19 +644,29 @@ static int input_key( int keynum, int value)
 static int input_key_event( SDLKey key, SDLMod mod, int value )
 {
     int i;
+    int noteaten = -1;
     mod &= ~(KMOD_CAPS | KMOD_NUM | KMOD_MODE); /* We want to ignore "global" modifiers. */
 
     for (i=0; strcmp(keybindNames[i],"end"); i++)
 	if ((GameConfig.input_keybinds[i].key == key) && (GameConfig.input_keybinds[i].mod==mod)) {
-	    if(!input_key(i, value))
+	    if(!(noteaten = input_key(i, value)))
 		break;
 	}
-    return 0;
+    return noteaten;
 }
 
-int input_key_press (SDLKey key, SDLMod mod)
+int input_key_press (SDL_Event *event)
 {
-    return input_key_event(key, mod, KEY_PRESS);
+    int noteaten;
+    noteaten = input_key_event(event->key.keysym.sym, event->key.keysym.mod, KEY_PRESS);
+
+    if (!noteaten)
+	return 0;
+    else if (INLVLEDIT()) {
+	leveleditor_input_keybevent(event);
+    }
+
+    return 0;
 }
 
 /**
