@@ -59,7 +59,7 @@ DoAllMovementAndAnimations ( void )
     
     WorkLevelGuns( ); // this should fire all autocannons on this level
     
-    CheckForTriggeredEventsAndStatements ( ) ;
+    CheckForTriggeredEvents ( ) ;
     
     AnimateCyclingMapTiles (); // this is a pure client issue.  Not dependent upon the players.
     
@@ -126,7 +126,7 @@ int
 main (int argc, char * argv[])
 {
 
-#if defined HAVE_LIBGEN_H && defined HAVE_UNISTD_H
+#if defined HAVE_UNISTD_H && defined HAVE_DIRNAME
     // change working directory to the executable's directory
     if ( chdir ( dirname ( argv [0] )))
         fprintf ( stderr, "Couldn't change working directory to %s.\n", dirname ( argv [0]));
@@ -204,6 +204,7 @@ better than nothing.  Thanks anyway for your interest in FreedroidRPG.\n\
     while (!QuitProgram)
     {
 	StartupMenu ( );
+	input_handle();
 	switch (game_root_mode) {
 	    case ROOT_IS_GAME:
 		Game ();
@@ -358,9 +359,9 @@ UpdateCountersForThisFrame ( )
     // In any case those counteres must be updated, but we'll only to 
     // that for the Tux current level (at present).
     //
-    for ( level_num = 0 ; level_num < MAX_LEVELS ; level_num ++ )
+    for ( level_num = 0 ; level_num < curShip.num_levels ; level_num ++ )
 	{
-	if ( level_is_visible ( level_num ) )
+	if ( (curShip.AllLevels[level_num] != NULL) && level_is_visible ( level_num ) )
 	    update_timeouts_for_bots_on_level ( level_num , latest_frame_time ) ;
 	}
 
@@ -455,8 +456,9 @@ UpdateCountersForThisFrame ( )
     // enemies, we keep track to the time spent actually in the game, i.e.
     // time actually spent passing frames...
     //
-    for ( i = 0 ; i < MAX_LEVELS ; i ++ )
+    for ( i = 0 ; i < curShip.num_levels ; i ++ )
 	{
+    	if ( curShip.AllLevels[i] == NULL ) continue;
 	if ( Me . pos . z != i )
 	    {
 	    if ( Me . time_since_last_visit_or_respawn [ i ] > (-1) )
@@ -470,8 +472,13 @@ UpdateCountersForThisFrame ( )
 	    //
 	    if ( Me . time_since_last_visit_or_respawn [ i ] > 600 )
 		{
+		/* Do not respawn the town. At all. */
+		if (!strcmp(curShip.AllLevels[i]->Levelname, "Town"))
+		    continue;
+
 		DebugPrintf ( -10 , "\nNow respawning all bots on level : %d. " , i ) ;
 		Me . time_since_last_visit_or_respawn [ i ] = 0 ;
+		
 		respawn_level ( i ) ;
 		}
 
