@@ -44,10 +44,8 @@
 #define WP_SECTION_BEGIN_STRING		"wp"
 #define LEVEL_END_STRING	"end_of_level"
 
-#define AREA_NAME_STRING "Area name=\""
 #define LEVEL_NAME_STRING "Name of this level=_\""
 #define LEVEL_NAME_STRING_LEGACY "Name of this level="
-#define LEVEL_ENTER_COMMENT_STRING "Infcmt=\""
 #define BACKGROUND_SONG_NAME_STRING "BgSong="
 #define MAP_END_STRING "/pmapinfolvl"
 
@@ -127,8 +125,8 @@
 //--------------------
 // Distance, where door opens 
 //
-#define DOOROPENDIST2 (1.0)
-#define DOOROPENDIST2_FOR_DROIDS (0.5)
+#define DOOROPENDIST2 (2.0)
+#define DOOROPENDIST2_FOR_DROIDS (1.0)
 
 //--------------------
 // How big is the margin the walls have as far as collisions are concerned.
