@@ -64,8 +64,7 @@ extern int load_game_command_came_from_inside_running_game;
  * This function tells over which menu item the mouse cursor would be,
  * if there were infinitely many menu items.
  */
-int
-MouseCursorIsOverMenuItem( int first_menu_item_pos_y , int h )
+static int MouseCursorIsOverMenuItem( int first_menu_item_pos_y , int h )
 {
     int PureFraction;
 
@@ -89,8 +88,7 @@ MouseCursorIsOverMenuItem( int first_menu_item_pos_y , int h )
  *
  *
  */
-void
-print_menu_text ( char* InitialText , char* MenuTexts[] , int first_menu_item_pos_y , int background_code , void* MenuFont ) 
+static void print_menu_text ( char* InitialText , char* MenuTexts[] , int first_menu_item_pos_y , int background_code , void* MenuFont ) 
 {
     char open_gl_string [ 2000 ];
     int h = FontHeight ( GetCurrentFont ( ) );
@@ -449,6 +447,8 @@ DoMenuSelection( char* InitialText , char **MenuTexts, int FirstItem , int backg
     
 out:
     free(MenuTextWidths);
+    while (MouseLeftPressed()) //eat the click that may have happened
+	SDL_Delay(1);
     game_status = old_game_status;
     return ret;
 }; // int DoMenuSelection( ... )
@@ -1198,28 +1198,38 @@ Cheatmenu (void)
 		break;
 
 	    case 'w':  /* print waypoint info of current level */
-		WpList = CURLEVEL->AllWaypoints;
+		WpList = CURLEVEL()->AllWaypoints;
 		for (i=0; i<MAXWAYPOINTS && WpList[i].x; i++)
 		{
 		    if (i && !(i%20))
 		    {
 			printf_SDL (Screen, -1, -1, " ---- MORE -----\n");
-			if (getchar_raw (NULL) == 'q')
+			our_SDL_flip_wrapper();
+			
+			if (getchar_raw (NULL) == 'q') {
+			    i = -1; //ugly hack to not getchar_raw twice in a row
 			    break;
+			}
 		    }
 		    if ( !(i%20) )
 		    {
 			ClearGraphMem ();
 			printf_SDL (Screen, x0, y0, "Nr.   X   Y      C1  C2  C3  C4\n");
 			printf_SDL (Screen, -1, -1, "------------------------------------\n");
-		    }		    printf_SDL (Screen, -1, -1, "%2d   %2d  %2d      %2d  %2d  %2d  %2d\n",
+		    }		    
+		    printf_SDL (Screen, -1, -1, "%2d   %2d  %2d      %2d  %2d  %2d  %2d\n",
 				i, WpList[i].x, WpList[i].y,
 				WpList[i].connections[0],
 				WpList[i].connections[1],
 				WpList[i].connections[2],
 				WpList[i].connections[3]);
 		} /* for (all waypoints) */
+
+		if (i == -1)
+		    break;
+
 		printf_SDL (Screen, -1, -1, " --- END ---\n");
+		our_SDL_flip_wrapper();
 		getchar_raw (NULL);
 		break;
 
@@ -1282,8 +1292,7 @@ struct Menu menus [] = {
 };
 
 
-void
-RunSubMenu (int startup, char buffer[10][1024], int menu_id)
+static void RunSubMenu (int startup, int menu_id)
 {
     int can_continue = 0;
     char *texts[10];
@@ -1293,7 +1302,7 @@ RunSubMenu (int startup, char buffer[10][1024], int menu_id)
 	int pos;
 	// We need to fill at each loop because
 	// several menus change their contents
-	for (i = 0; i < 9; i++) texts[i] = buffer[i];
+	for (i = 0; i < 10; i++) texts[i] = (char*)malloc(1024*sizeof(char));
 	menus [ menu_id ] . FillText ( texts );
 	
 	if (startup)
@@ -1303,20 +1312,20 @@ RunSubMenu (int startup, char buffer[10][1024], int menu_id)
 	
 	int ret = menus [ menu_id ] . HandleSelection (pos);
 	
+	for (i = 0; i < 10; i++) free(texts[i]);
+	
 	if (ret == EXIT_MENU) 
 	{
 	    can_continue = TRUE;
 	}
 	
 	if (ret > 0)
-	    RunSubMenu (startup, buffer, ret);
+	    RunSubMenu (startup, ret);
     }
 }
-void 
-RunMenu (int is_startup)
+
+static void RunMenu (int is_startup)
 {
-	// 1024 should be enough
-	char buffer [10][1024]; 
 	int start_menu = is_startup ? MENU_STARTUP : MENU_ESCAPE;
 	SetCurrentFont ( Menu_BFont );
 	Activate_Conservative_Frame_Computation ( ) ;	
@@ -1330,8 +1339,7 @@ RunMenu (int is_startup)
 	} else {
 	    while ( EscapePressed() );
 	}
-	RunSubMenu (is_startup, buffer, start_menu);
-	Me.status=MOBILE;
+	RunSubMenu (is_startup, start_menu);
 	ClearGraphMem();
 }
 
@@ -1351,6 +1359,7 @@ Startup_handle (int n)
     enum
     { 
 	SINGLE_PLAYER_POSITION=1, 
+	TUTORIAL_POSITION,
 	LVLEDIT_POSITION,
 	OPTIONS_POSITION,
 	CREDITS_POSITION,
@@ -1365,19 +1374,32 @@ Startup_handle (int n)
 		return EXIT_MENU;
 	    }
 	    break;
-    case LVLEDIT_POSITION: //allow starting directly in leveleditor - the hack is a little dirty but it does its work.
-	skip_initial_menus = 1;
-	clear_player_inventory_and_stats ( ) ;
-	UpdateAllCharacterStats ( ) ;
-	strcpy(Me.character_name, "MapEd");
-	char fp[2048];
-	find_file ( "freedroid.levels" , MAP_DIR, fp, 0);
-	LoadShip ( fp ) ;
-	PrepareStartOfNewCharacter ( ) ;
-	skip_initial_menus = 0;
-	game_root_mode = ROOT_IS_LVLEDIT;
-	return EXIT_MENU;
-	break;  
+	case LVLEDIT_POSITION: //allow starting directly in leveleditor - the hack is a little dirty but it does its work.
+		skip_initial_menus = 1;
+		clear_player_inventory_and_stats ( ) ;
+		UpdateAllCharacterStats ( ) ;
+		strcpy(Me.character_name, "MapEd");
+		char fp[2048];
+		find_file ( "freedroid.levels" , MAP_DIR, fp, 0);
+		LoadShip ( fp ) ;
+		PrepareStartOfNewCharacter ( "NewTuxStartGameSquare" ) ;
+		skip_initial_menus = 0;
+		game_root_mode = ROOT_IS_LVLEDIT;
+		return EXIT_MENU;
+		break;
+	case TUTORIAL_POSITION: //Similar hack to start Tutorial.
+		skip_initial_menus = 1;
+		clear_player_inventory_and_stats ( ) ;
+		UpdateAllCharacterStats ( ) ;
+		strcpy(Me.character_name, "TutorialTux");
+		char fpp[2048];
+		find_file ( "freedroid.levels" , MAP_DIR, fpp, 0);
+		LoadShip ( fpp ) ;
+		PrepareStartOfNewCharacter ( "TutorialTuxStart" ) ;
+		skip_initial_menus = 0;
+		game_root_mode = ROOT_IS_GAME;
+		return EXIT_MENU;
+		break;
     case OPTIONS_POSITION:
 	return MENU_OPTIONS;
     case CREDITS_POSITION:
@@ -1399,13 +1421,15 @@ Startup_handle (int n)
 static void
 Startup_fill (char *MenuTexts[10])
 {
-    MenuTexts[0]=_("Play");
-    MenuTexts[1]=_("Level Editor");
-    MenuTexts[2]=_("Options");
-    MenuTexts[3]=_("Credits");
-    MenuTexts[4]=_("Contribute");
-    MenuTexts[5]=_("Exit FreedroidRPG");
-    MenuTexts[6]="";
+	int i = 0;
+	strncpy(MenuTexts[i++], _("Play"), 1024);
+	strncpy(MenuTexts[i++], _("Tutorial"), 1024);
+	strncpy(MenuTexts[i++], _("Level Editor"), 1024);
+	strncpy(MenuTexts[i++], _("Options"), 1024);
+	strncpy(MenuTexts[i++], _("Credits"), 1024);
+	strncpy(MenuTexts[i++], _("Contribute"), 1024);
+	strncpy(MenuTexts[i++], _("Exit FreedroidRPG"), 1024);
+	MenuTexts[i++][0]='\0';
 }
 
 
@@ -1416,6 +1440,7 @@ Options_handle (int n)
 	{ 
 	    GRAPHICS_OPTIONS=1, 
 	    SOUND_OPTIONS,
+	    KEYMAP_OPTIONS,
 	    LANGUAGE_OPTIONS,
 	    DROID_TALK_OPTIONS,
 	    ON_SCREEN_DISPLAYS,
@@ -1431,6 +1456,9 @@ Options_handle (int n)
 	    return MENU_GRAPHICS;
     case SOUND_OPTIONS:
 	    return MENU_SOUND;
+    case KEYMAP_OPTIONS:
+	    keychart();
+	    return CONTINUE_MENU;
     case LANGUAGE_OPTIONS:
 #if ENABLE_NLS
 #if defined(__WIN32__) || defined(__MACOSX__)
@@ -1467,14 +1495,15 @@ Options_handle (int n)
 static void
 Options_fill (char *MenuTexts [10])
 {
-	MenuTexts[0]=_("Graphics Options");
-	MenuTexts[1]=_("Sound Options");
-	MenuTexts[2]=_("Language");
-	MenuTexts[3]=_("Droid Talk");
-	MenuTexts[4]=_("On-Screen Displays");
-	MenuTexts[5]=_("Performance Tweaks");
-	MenuTexts[6]=_("Back");
-	MenuTexts[7]="";
+	strncpy(MenuTexts[0], _("Graphics Options"), 1024);
+	strncpy(MenuTexts[1], _("Sound Options"), 1024);
+	strncpy(MenuTexts[2], _("Keys"), 1024);
+	strncpy(MenuTexts[3], _("Language"), 1024);
+	strncpy(MenuTexts[4], _("Droid Talk"), 1024);
+	strncpy(MenuTexts[5], _("On-Screen Displays"), 1024);
+	strncpy(MenuTexts[6], _("Performance Tweaks"), 1024);
+	strncpy(MenuTexts[7], _("Back"), 1024);
+	MenuTexts[8][0]='\0';
 }
 
 static int
@@ -1524,97 +1553,99 @@ static void
 Escape_fill (char *MenuTexts [10])
 {
       if (game_root_mode == ROOT_IS_GAME)
-	  MenuTexts[0]=_("Resume Play");
+	  strncpy(MenuTexts[0], _("Resume Play"), 1024);
       else 
-	  MenuTexts[0]=_("Resume Playtest");
-      MenuTexts[1]=_("Save Hero");
-      MenuTexts[2]=_("Options");
-      MenuTexts[3]=_("Load Latest");
-      MenuTexts[4]=_("Load Backup");
+	  strncpy(MenuTexts[0], _("Resume Playtest"), 1024);
+	  
+      strncpy(MenuTexts[1], _("Save Hero"), 1024);
+      strncpy(MenuTexts[2], _("Options"), 1024);
+      strncpy(MenuTexts[3], _("Load Latest"), 1024);
+      strncpy(MenuTexts[4], _("Load Backup"), 1024);
       if (game_root_mode == ROOT_IS_GAME)
-	  MenuTexts[5]=_("Quit to Main Menu");
+	  strncpy(MenuTexts[5], _("Quit to Main Menu"), 1024);
       else 
-	  MenuTexts[5]=_("Return to Level Editor");
-      MenuTexts[6]=_("Exit FreedroidRPG");
-      MenuTexts[7]="";
+	  strncpy(MenuTexts[5], _("Return to Level Editor"), 1024);
+      strncpy(MenuTexts[6], _("Exit FreedroidRPG"), 1024);
+      MenuTexts[7][0]='\0';
 }
 
+extern screen_resolution screen_resolutions[];
+
 static int
 Resolution_handle (int n)
 {
-    enum
-	{ 
-	    SET_640_480 = 1 , 
-	    SET_800_600, 
-	    SET_1024_768,
-	    SET_1152_864,
-	    SET_1280_960,
-/*
-	    SET_1280_1024,
-	    SET_1280_800,
-	    SET_1440_900,
-	    SET_1680_1050,
-*/
-	    LEAVE_OPTIONS_MENU 
-	};
-#define MSG(x, y) "\n"				\
-	"You selected "#x "x" #y"pixel.\n\n"	\
-	"Change of screen resolution will\n"	\
-	"take effect automatically when you next\n"	\
-	"start FreedroidRPG.\n"				\
-	"\n"						\
-	"Thank you.\n"					\
+	if ( n == -1 ) return EXIT_MENU;
 	
-#define CASE(x, y) case SET_##x##_##y:		\
-    while (EnterPressed ( ) || SpacePressed ( )); \
-    GameConfig . next_time_width_of_screen = x ;	\
-    GameConfig . next_time_height_of_screen = y ;	\
-    GiveMouseAlertWindow (_(MSG(x,y)));			\
-    break;
+	// First value of 'n' is '1', so decrement it.
+	--n;
+	
+	int nb_res = 0;
+	int nb_supported_res = 0;
+	while ( screen_resolutions[nb_res].xres != -1 )
+	{
+		if ( screen_resolutions[nb_res].supported ) ++nb_supported_res;
+		++nb_res;
+	}
+	
+	// Last menu entry is 'Back'
+	if ( n == nb_supported_res ) { while ( EnterPressed() || SpacePressed() ); return EXIT_MENU; }
+	
+	// Wrong entry. How is it possible ???
+	if ( n < 0 || n > nb_supported_res ) return CONTINUE_MENU;
 
-    switch (n) 
-    {
-    case (-1):
-	return EXIT_MENU;
+	int i, j;
+	for (i=0, j=0; i<nb_res; ++i)
+	{
+		// Only supported screen resolution are displayed
+		if ( !screen_resolutions[i].supported ) continue;
+		
+		// Is the current supported resolution the selected one ?
+		if ( n == j )
+		{
+			while ( EnterPressed() || SpacePressed() );
+			GameConfig.next_time_width_of_screen = screen_resolutions[i].xres;
+			GameConfig.next_time_height_of_screen = screen_resolutions[i].yres;
+			char* fmt = _("\nYou selected %d x %d pixel.\n\n"
+			              "Change of screen resolution will\n"
+			              "take effect automatically when you next\n"
+			              "start FreedroidRPG.\n"
+			              "\n"
+			              "Thank you.\n");
+			char* txt = (char*)malloc(strlen(fmt)+20); // 20 chars should be enough to store 2 integers
+			sprintf(txt, fmt, screen_resolutions[i].xres, screen_resolutions[i].yres);
+			GiveMouseAlertWindow (txt);
+			free(txt);
+			return CONTINUE_MENU;
+		}
+		++j;
+	}
 	
-    CASE(640,480);
-    CASE(800,600);
-    CASE(1024,768);
-    CASE(1152,864);
-    CASE(1280,960);
-/*
-    CASE(1280,1024);
-    CASE(1280,800);
-    CASE(1440,900);
-    CASE(1680,1050);
-*/
-    case LEAVE_OPTIONS_MENU:
-	while (EnterPressed() || SpacePressed() );
-	return EXIT_MENU;
-    default: 
-	break;
-    } 
-    return CONTINUE_MENU;
+	return CONTINUE_MENU;
 }
 
 static void
 Resolution_fill (char *MenuTexts[10])
 {
-    sprintf( MenuTexts[0] , "%c 640x480", GameConfig . next_time_height_of_screen==480 ? '*' : ' ' );
-    sprintf( MenuTexts[1] , "%c 800x600", GameConfig . next_time_height_of_screen==600 ? '*' : ' ' );
-    sprintf( MenuTexts[2] , "%c 1024x768", GameConfig . next_time_height_of_screen==768 ? '*' : ' ' );
-    sprintf( MenuTexts[3] , "%c 1152x864", GameConfig . next_time_height_of_screen==864 ? '*' : ' ' );
-    sprintf( MenuTexts[4] , "%c 1280x960", GameConfig . next_time_height_of_screen==960 ? '*' : ' ' );
-    MenuTexts[5]=_("Back");
-    MenuTexts[6]="";
-/*
-    sprintf( MenuTexts[4] , "%c 1280x1024", GameConfig . next_time_height_of_screen==1024 ? '*' : ' ' );
-    sprintf( MenuTexts[5] , "%c 1280x800", GameConfig . next_time_height_of_screen==800 ? '*' : ' ' );
-    sprintf( MenuTexts[6] , "%c 1440x900", GameConfig . next_time_height_of_screen==900 ? '*' : ' ' );
-    sprintf( MenuTexts[7] , "%c 1680x1050", GameConfig . next_time_height_of_screen==1050 ? '*' : ' ' );
-    MenuTexts[8]=_("Back");
-    MenuTexts[9]="";
-*/
+    int i=0;
+    int j=0;
+
+    while ( screen_resolutions[i].xres != -1 )
+    {
+    	//Only supported screen resolution are displayed
+    	if ( screen_resolutions[i].supported ) {
+    		char flag = ' ';
+    		if ( GameConfig.next_time_width_of_screen == screen_resolutions[i].xres &&
+    		     GameConfig.next_time_height_of_screen == screen_resolutions[i].yres
+    		   ) 
+    		{
+    			flag = '*';
+    		}
+    		sprintf( MenuTexts[j++], "%c %dx%d", flag, screen_resolutions[i].xres, screen_resolutions[i].yres);
+    	}
+    	++i;
+    }
+    strncpy(MenuTexts[j++], _("Back"), 1024);
+    MenuTexts[j++][0]='\0';
 }
 
 static int
@@ -1622,9 +1653,9 @@ Graphics_handle (int n)
 {
     enum
     { 
-	SET_GAMMA_CORRECTION = 1 , 
+	CHANGE_SCREEN_RESOLUTION = 1,
 	SET_FULLSCREEN_FLAG, 
-	CHANGE_SCREEN_RESOLUTION,
+	SET_GAMMA_CORRECTION,
 	SET_SHOW_BLOOD_FLAG,
 	SET_AUTOMAP_SCALE,
 	LEAVE_OPTIONS_MENU 
@@ -1700,15 +1731,27 @@ Graphics_handle (int n)
 static void
 Graphics_fill (char *MenuTexts[10])
 {
-	sprintf( MenuTexts[0] , _("Gamma Correction: %1.2f"), GameConfig.current_gamma_correction );
-	sprintf( MenuTexts[1] , _("Fullscreen Mode: %s"), GameConfig . fullscreen_on ? _("ON") : _("OFF"));
-	sprintf( MenuTexts[2] , _("Change Screen Resolution") );
-	sprintf( MenuTexts[3] , _("Show Blood: %s"), 
-		 GameConfig . show_blood ? _("YES") : _("NO") );
-	sprintf( MenuTexts[4] , _("Automap Scale: %2.1f"), 
-		 GameConfig . automap_display_scale );
-	MenuTexts[5]=_("Back");
-	MenuTexts[6]="";
+	char Options [ 20 ] [1000];
+	int i = 0;
+	sprintf( MenuTexts[i++] , _("Change Screen Resolution"));
+		sprintf( Options [ i ] , _("Fullscreen Mode"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.fullscreen_on ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Gamma Correction"));
+		sprintf( Options [ i+1 ] , ": %1.2f", GameConfig.current_gamma_correction );
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Show Blood"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.show_blood ? _("YES") : _("NO"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Automap Scale"));
+		sprintf( Options [ i+1 ] , ": %2.1f", GameConfig.automap_display_scale );
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	strncpy(MenuTexts[i++], _("Back"), 1024);
+	MenuTexts[i++][0]='\0';
 }
 
 
@@ -1773,10 +1816,18 @@ Sound_handle (int n)
 static void
 Sound_fill (char *MenuTexts[10])
 {
-	sprintf ( MenuTexts[0] , _("Background Music Volume: %1.2f") , GameConfig.Current_BG_Music_Volume );
-	sprintf ( MenuTexts[1] , _("Sound Effects Volume: %1.2f"), GameConfig.Current_Sound_FX_Volume );
-	MenuTexts [ 2 ] = _("Back");
-	MenuTexts [ 3 ] = "";
+	char Options [ 20 ] [1000];
+	int i = 0;
+		sprintf( Options [ i ] , _("Background Music Volume"));
+		sprintf( Options [ i+1 ] , ": %1.2f", GameConfig.Current_BG_Music_Volume );
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Sound Effects Volume"));
+		sprintf( Options [ i+1 ] , ": %1.2f", GameConfig.Current_Sound_FX_Volume );
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	strncpy(MenuTexts[i++], _("Back"), 1024);
+	MenuTexts[i++][0]='\0';
 }
 
 
@@ -1838,16 +1889,30 @@ Performance_handle (int n)
 static void
 Performance_fill (char *MenuTexts[])
 {
-	sprintf ( MenuTexts[0] , _("Hog CPU for max. performance: %s"), 
-		  GameConfig.hog_CPU ? _("YES") : _("NO") );
-	sprintf ( MenuTexts[1] , _("Highlighting mode: %s"), GameConfig.highlighting_mode_full ? _("FULL") : _("REDUCED") );
-	sprintf ( MenuTexts[2] , _("Skip light radius: %s"), GameConfig . skip_light_radius ? _("YES") : _("NO") );
-	sprintf ( MenuTexts[3] , _("Skip shadow blitting: %s"), 
-		  GameConfig . skip_shadow_blitting ? _("YES") : _("NO") );
-	sprintf( MenuTexts[4] , _("Skip fadings: %s"), 
-		 GameConfig . do_fadings ? _("NO") : _("YES") );
-	MenuTexts[5]=_("Back");
-	MenuTexts[6]="";
+	char Options [ 20 ] [1000];
+	int i = 0;
+		sprintf( Options [ i ] , _("Hog CPU for max. performance"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.hog_CPU ? _("YES") : _("NO"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Highlighting mode"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.highlighting_mode_full ? _("FULL") : _("REDUCED"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Skip light radius"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.skip_light_radius ? _("YES") : _("NO"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+		strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	sprintf( Options [ i ] , _("Skip shadow blitting"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.skip_shadow_blitting ? _("YES") : _("NO"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+		strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	sprintf( Options [ i ] , _("Skip fadings"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.do_fadings ? _("NO") : _("YES") );
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	strncpy(MenuTexts[i++], _("Back"), 1024);
+	MenuTexts[i++][0]='\0';
 }
 
 static int
@@ -1876,10 +1941,10 @@ Language_fill (char *MenuTexts[10])
     int i = 0;
     while ( supported_languages[i].code != NULL )
 	{
-	MenuTexts[i] = supported_languages[i].name;
+	strncpy(MenuTexts[i], supported_languages[i].name, 1024);
 	i ++;
 	}
-    MenuTexts[i] = "";
+    MenuTexts[i][0] = '\0';
 }
 
 
@@ -1958,7 +2023,7 @@ OSD_fill (char *MenuTexts[10])
 {
       sprintf( MenuTexts[0] , _("Show Position: %s"), GameConfig.Draw_Position ? _("ON") : _("OFF") );
       sprintf( MenuTexts[1] , _("Show Framerate: %s"), GameConfig.Draw_Framerate? _("ON") : _("OFF") );
-      sprintf( MenuTexts[2] , _("Show Enemy Energy Bars: %s"), GameConfig.enemy_energy_bars_visible? _("ON") : _("OFF") );
+      sprintf( MenuTexts[2] , _("Show Energy Bars: %s"), GameConfig.enemy_energy_bars_visible? _("ON") : _("OFF") );
       sprintf( MenuTexts[3] , _("Screen Messages at most: %d"), GameConfig.number_of_big_screen_messages );
       sprintf( MenuTexts[4] , _("Screen Message time: %3.1f"), GameConfig.delay_for_big_screen_messages );
       strcpy (MenuTexts[5], _("Back"));
@@ -1997,13 +2062,30 @@ Droid_handle (int n)
 static void
 Droid_fill (char *MenuTexts[10])
 {
-      sprintf( MenuTexts[0] , _("Enemy Hit Texts: %s"), GameConfig.Enemy_Hit_Text ? _("ON") : _("OFF") );
-      sprintf( MenuTexts[1] , _("Enemy Bumped Texts: %s"), GameConfig.Enemy_Bump_Text ? _("ON") : _("OFF") );
-      sprintf( MenuTexts[2] , _("Enemy Aim Texts: %s"), GameConfig.Enemy_Aim_Text ? _("ON") : _("OFF") );
-      sprintf( MenuTexts[3] , _("All in-game Speech: %s"), GameConfig.All_Texts_Switch ? _("ON") : _("OFF") );
-      sprintf( MenuTexts[4], _("Reprogram bots after takeover: %s"), GameConfig.talk_to_bots_after_takeover ? _("ON") : _("OFF"));
-      MenuTexts[5] = _("Back");
-      MenuTexts[6] = "";
+	char Options [ 20 ] [1000];
+	int i = 0;
+		sprintf( Options [ i ] , _("Enemy Hit Texts"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.Enemy_Hit_Text ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Enemy Bumped Texts"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.Enemy_Bump_Text ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Enemy Aim Texts"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.Enemy_Aim_Text ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("All in-game Speech"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.All_Texts_Switch ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+		sprintf( Options [ i ] , _("Reprogram bots after takeover"));
+		sprintf( Options [ i+1 ] , ": %s", GameConfig.talk_to_bots_after_takeover ? _("ON") : _("OFF"));
+		strcat( Options [ i ] , Options [ i+1 ] );
+	strncpy(MenuTexts[ i ], Options [ i ], 1024); i++ ;
+	strncpy(MenuTexts[i++], _("Back"), 1024);
+	MenuTexts[i++][0]='\0';
 }
 
     
@@ -2013,8 +2095,7 @@ Droid_fill (char *MenuTexts[10])
 /**
  * This reads in the new name for the character...
  */
-void
-Get_New_Character_Name ( void )
+static void Get_New_Character_Name ( void )
 {
     char* Temp;
     InitiateMenu( NE_TITLE_PIC_BACKGROUND_CODE );
@@ -2124,8 +2205,7 @@ clear_player_inventory_and_stats ( void )
 /**
  * This function prepares a new hero for adventure...
  */
-int
-PrepareNewHero (void)
+static int PrepareNewHero (void)
 {
 
     clear_player_inventory_and_stats ( ) ;
@@ -2194,6 +2274,7 @@ static int do_savegame_selection_and_act(int action)
     int saveoffset = 0;
     char SafetyText[500];
     char *menu_title = NULL;
+    int rtn;
     
     switch (action) {
 	case SAVEGAME_LOAD:
@@ -2305,12 +2386,18 @@ static int do_savegame_selection_and_act(int action)
     return FALSE;
 
 do_action:    
+	rtn = FALSE;
     switch (action) {
 	case SAVEGAME_LOAD:
 	    if ( LoadGame ( ) == OK ) {
-		GetEventsAndEventTriggers ( "freedroid.events" );
+		GetEventTriggers ( "freedroid.events" );
 		GetQuestList ( "freedroid.quests" );
 		Item_Held_In_Hand = ( -1 );
+		rtn = TRUE;
+	    } 
+	    else
+	    {
+	    rtn = FALSE;
 	    }
 	    break;
 	case SAVEGAME_DELETE:
@@ -2324,17 +2411,18 @@ do_action:
 
 	    if ( FinalDecision == 1 )
 		DeleteGame( );
+	    rtn = TRUE;
 	    break;
     }
 
     our_SDL_flip_wrapper();
-    return TRUE;
+    return rtn;
 }
 
 /**
  * Load a savegame
  */
-int Load_Existing_Hero_Menu ( void )
+static int Load_Existing_Hero_Menu ( void )
 {
     return do_savegame_selection_and_act(SAVEGAME_LOAD);
 }
@@ -2342,7 +2430,7 @@ int Load_Existing_Hero_Menu ( void )
 /** 
  * Delete a savegame
  */
-int Delete_Existing_Hero_Menu ( void )
+static int Delete_Existing_Hero_Menu ( void )
 {
     return do_savegame_selection_and_act(SAVEGAME_DELETE);
 }
@@ -2396,7 +2484,7 @@ Single_Player_Menu (void)
 		    char fp[2048];
 		    find_file ( "freedroid.levels" , MAP_DIR, fp, 0);
 		    LoadShip ( fp ) ;
-		    PrepareStartOfNewCharacter ( ) ;
+		    PrepareStartOfNewCharacter ( "NewTuxStartGameSquare" ) ;
 		    can_continue=TRUE;
 		    load_game_command_came_from_inside_running_game = TRUE ;
 		    return ( TRUE );
