@@ -26,10 +26,6 @@
 /**
  * This file contains miscellaeous helpful functions for Freedroid.
  */
-/*
- * This file has been checked for remains of german comments in the code
- * I you still find some, please just kill it mercilessly.
- */
 #define _misc_c
 
 #include "system.h"
@@ -49,20 +45,23 @@
 #  include <signal.h>
 #endif
 
-//--------------------
-// The definition of the message structure can stay here,
-// because its only needed in this module.
-//
-typedef struct
-{
-  void *NextMessage;
-  int MessageCreated;
-  char *MessageText;
-}
-message, Message;
-
 extern SDL_Surface *zoomSurface(SDL_Surface * src, double zoomx, double zoomy, int smooth);
 
+long oneframedelay = 0;
+long tenframedelay = 0;
+long onehundredframedelay = 0;
+float FPSover1 = 10;
+float FPSover10 = 10;
+float FPSover100 = 10;
+Uint32 Now_SDL_Ticks;
+Uint32 One_Frame_SDL_Ticks;
+Uint32 Ten_Frame_SDL_Ticks;
+Uint32 Onehundred_Frame_SDL_Ticks;
+int framenr = 0;
+
+char *our_homedir = NULL;
+char *our_config_dir = NULL;
+
 
 mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
 {
@@ -86,8 +85,10 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     /*RIGHT_SHOP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/RightShopButton.png"              , { 576 , 447 ,  26 ,  26 } , TRUE , FALSE } ,
     /*LEFT_TUX_SHOP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LeftShopButton.png"               , {   5 ,  16 ,  26 ,  26 } , TRUE , FALSE } ,
     /*RIGHT_TUX_SHOP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/RightShopButton.png"              , { 580 ,  13 ,  26 ,  26 } , TRUE , FALSE } ,
-    /*LEFT_LEVEL_EDITOR_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorLeft.png", {  3 ,  25 ,  15 ,  60 } , FALSE , FALSE } ,
-    /*RIGHT_LEVEL_EDITOR_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorRight.png", { 620 ,  26 ,  15 ,  60 } , FALSE , FALSE } ,
+    /*LEFT_LEVEL_EDITOR_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorLeft.png", {  3 ,  8 ,  15 ,  60 } , FALSE , FALSE } ,
+    /*LEFT_LEVEL_EDITOR_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorLeft.png", {  3 ,  8 ,  15 ,  60 } , FALSE , FALSE } ,
+    /*RIGHT_LEVEL_EDITOR_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorRight.png", { -16 ,  8 ,  15 ,  60 } , FALSE , FALSE } ,
+    /*RIGHT_LEVEL_EDITOR_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorRight.png", { -16 ,  8 ,  15 ,  60 } , FALSE , FALSE } ,
 
 
     /*NUMBER_SELECTOR_OK_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/number_selector_ok_button.png"    , { 308 , 288 ,  48 ,  48 } , TRUE , FALSE } ,
@@ -147,8 +148,6 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     /*LEVEL_EDITOR_ESC_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorESCButtonPushed.png"         , { 430 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_LEVEL_RESIZE_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorResizeLevelButton.png" , { 460 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_LEVEL_RESIZE_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorResizeLevelButtonPushed.png" , { 460 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_KEYMAP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorKeymapButton.png"      , { -120 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_KEYMAP_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorKeymapButtonPushed.png"      , { -120 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_QUIT_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorQuitButton.png"        , { -30 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_QUIT_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorQuitButtonPushed.png"        , { -30 , 90 , 0 ,  0 } , FALSE , FALSE } ,
 
@@ -159,10 +158,6 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     /*LEVEL_EDITOR_UNDERGROUND_LIGHT_OFF_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorUndergroundLightOffButtonPushed.png" , { -30 , 150 , 30 ,  30 } , FALSE , FALSE } ,
 
 
-    /*LEVEL_EDITOR_TOGGLE_TUX_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleTuxButton.png"        , { 210 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_TOGGLE_TUX_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleTuxButtonPushed.png"        , { 210 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_TOGGLE_TUX_BUTTON_OFF*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleTuxButtonOff.png"        , { 210 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_TOGGLE_TUX_BUTTON_OFF_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleTuxButtonOffPushed.png"        , { 210 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_TOGGLE_ENEMIES_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleEnemiesButton.png"    , { 240 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_TOGGLE_ENEMIES_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleEnemiesButtonPushed.png"    , { 240 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_TOGGLE_ENEMIES_BUTTON_OFF*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleEnemiesButtonOff.png"    , { 240 , 90 , 0 ,  0 } , FALSE , FALSE } ,
@@ -179,13 +174,13 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     /*LEVEL_EDITOR_TOGGLE_COLLISION_RECTS_BUTTON_PUSHED */    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleCollisionRectsButtonPushed.png"  , { 330 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     /*LEVEL_EDITOR_TOGGLE_COLLISION_RECTS_BUTTON_OFF*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleCollisionRectsButtonOff.png"  , { 330 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     /*LEVEL_EDITOR_TOGGLE_COLLISION_RECTS_BUTTON_OFF_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleCollisionRectsButtonOffPushed.png"  , { 330 , 90 , 0 ,  0 } , FALSE , FALSE } , 
+    /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_OFF*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonOff.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,
+    /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_OFF_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonOffPushed.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,  
+
     /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButton.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonPushed.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_FULL*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonFull.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,
     /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_FULL_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonFullPushed.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,  
-    /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_OFF*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonOff.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,
-    /*LEVEL_EDITOR_TOGGLE_GRID_BUTTON_OFF_PUSHED*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonOffPushed.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } ,  
-
     /*LEVEL_EDITOR_NEXT_ITEM_GROUP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorNextItemGroup.png"     , { 55 + 64 * 8 , 32+5*66 , 0 ,  0 } , TRUE , FALSE } ,
     /*LEVEL_EDITOR_PREV_ITEM_GROUP_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorPrevItemGroup.png"     , { 55          , 32+5*66 , 0 ,  0 } , TRUE , FALSE } ,
     /*LEVEL_EDITOR_NEXT_PREFIX_BUTTON*/    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorNextItemGroup.png"     , { 55 + 400    , 32+5*66 , 0 ,  0 } , TRUE , FALSE } ,
@@ -568,9 +563,9 @@ char fpath[2048];
     if ( ( ButtonIndex >= MAX_MOUSE_PRESS_BUTTONS ) || ( ButtonIndex < 0 ) )
     {
 	ErrorMessage ( __FUNCTION__  , 
-				   "A Button that should be displayed on the screen was requested, but the\n\
+				   "Request to display button index %d could not be fulfilled: the\n\
 button index given exceeds the number of buttons defined in freedroid.",
-				   PLEASE_INFORM, IS_FATAL );
+				   PLEASE_INFORM, IS_FATAL, ButtonIndex );
     }
     
     //--------------------
@@ -668,39 +663,6 @@ This is an indication of a severe bug/installation problem of freedroid.",
     
 }; // void ShowGenericButtonFromList ( int ButtonIndex )
 
-
-#define SETTINGS_STRUCTURE_RAW_DATA_STRING "\nSettings Raw Data:\n"
-#define END_OF_SETTINGS_DATA_STRING "\nEnd of Settings File.\n"
-
-#define MESPOSX 0
-#define MESPOSY 64
-#define MESHOEHE 8
-#define MESBARBREITE 320
-#define MAX_MESSAGE_LEN 100
-#define MESBAR_MEM MESBARBREITE*MESHOEHE+1000
-
-void CreateMessageBar (char *MText);
-void AdvanceQueue (void);
-
-unsigned char *MessageBar;
-message *Queue = NULL;
-// int ThisMessageTime=0;               /* Counter fuer Message-Timing */
-
-long oneframedelay = 0;
-long tenframedelay = 0;
-long onehundredframedelay = 0;
-float FPSover1 = 10;
-float FPSover10 = 10;
-float FPSover100 = 10;
-Uint32 Now_SDL_Ticks;
-Uint32 One_Frame_SDL_Ticks;
-Uint32 Ten_Frame_SDL_Ticks;
-Uint32 Onehundred_Frame_SDL_Ticks;
-int framenr = 0;
-
-char *our_homedir = NULL;
-char *our_config_dir = NULL;
-
 /* -----------------------------------------------------------------
  * find a given filename in subdir relative to FD_DATADIR, 
  *
@@ -885,11 +847,7 @@ ComputeFPSForThisFrame(void)
   // defined in time.h or so.
   // 
   // I have arranged for a definition set in defs.h to switch between the two
-  // methods of ramerate calculation.  THIS MIGHT INDEED MAKE SENSE, SINCE THERE
-  // ARE SOME UNEXPLAINED FRAMERATE PHENOMENA WHICH HAVE TO TO WITH KEYBOARD
-  // SPACE KEY, SO PLEASE DO NOT ERASE EITHER METHOD.  PLEASE ASK JP FIRST.
-  //
-
+  // methods of ramerate calculation.  
 #ifdef USE_SDL_FRAMERATE
 
   Now_SDL_Ticks = SDL_GetTicks();
@@ -1229,7 +1187,6 @@ move_all_items_to_level ( int target_level )
 void
 Teleport ( int LNum , float X , float Y , int with_sound_and_fading )
 {
-    int array_num = 0;
     int i;
     char game_message_text [ 500 ] ;
 
@@ -1280,10 +1237,11 @@ Teleport ( int LNum , float X , float Y , int with_sound_and_fading )
 	// We add some sanity check against teleporting to non-allowed
 	// locations (like outside of map that is)
 	//
-	if ( ( LNum < 0 ) || ( Me . pos . x < 0 ) || ( Me . pos . y < 0 ) ||
-	     ( LNum >= curShip.num_levels ) || 
-	     ( Me . pos . x >= curShip.AllLevels[ array_num ] -> xlen ) ||
-	     ( Me . pos . y >= curShip.AllLevels[ array_num ] -> ylen ) )
+	if ( ( LNum < 0 ) || ( LNum >= curShip.num_levels ) || 
+	     ( Me . pos . x < 0 ) || ( Me . pos . y < 0 ) ||
+	     ( curShip.AllLevels[LNum] == NULL ) ||
+	     ( Me . pos . x >= curShip.AllLevels[ LNum ] -> xlen ) ||
+	     ( Me . pos . y >= curShip.AllLevels[ LNum ] -> ylen ) )
 	{
 	    fprintf( stderr, "\n\ntarget location was: lev=%d x=%f y=%f.\n" , LNum , X , Y );
 	    fprintf( stderr, "source location was: lev=%d x=%f y=%f." , Me . pos . z , 
@@ -1353,7 +1311,7 @@ This indicates an error in the map system of Freedroid.",
     //
     // if ( Shuffling ) ShuffleEnemys ( array_num );
     
-    SwitchBackgroundMusicTo( CURLEVEL->Background_Song_Name );
+    SwitchBackgroundMusicTo( CURLEVEL()->Background_Song_Name );
     
     //--------------------
     // Since we've mightily changed position now, we should clear the
@@ -1374,23 +1332,6 @@ This indicates an error in the map system of Freedroid.",
 
 }; // void Teleport( ... ) 
 
-/**
- * I'd like to use the function strnlen in LoadSettings, but this would
- * be a gnu extension. so I have to write this function myselt in order
- * to keep the code completely portable.
- */
-int
-mystrnlen ( char* MyString , int MyMaxlen )
-{
-  int i;
-
-  for ( i = 0 ; i < MyMaxlen ; i ++ )
-    {
-      if ( MyString [ i ] == 0 ) return i;
-    }
-  return MyMaxlen;
-}; // int mystrnlen ( char* MyString , int MyMaxlen )
-
 /*----------------------------------------------------------------------
  * LoadGameConfig(): load saved options from config-file
  *
@@ -1426,18 +1367,7 @@ LoadGameConfig (void)
     SaveGameFile = NULL;
     free(stuff);
     
-    //--------------------
-    // Now we do some extra security check:  Maybe the old settings file
-    // was generated by a different version of freedroid.  Then extra care
-    // must be taken:  The misinterpretation of values could case segmentation
-    // faults and things like that.
-    //
-    // For this purpose I'd like to use the function 'strnlen' but this would be 
-    // a gnu extension and not standard C, so I have to use the 'mystrlen' function
-    // taken from the gnu c manual.
-    //
-    if ( ( mystrnlen ( GameConfig.freedroid_version_string , 100 ) != strlen ( VERSION ) ) ||
-	 ( memcmp ( GameConfig.freedroid_version_string , VERSION , strlen ( VERSION ) ) ) )
+    if ( strcmp ( GameConfig.freedroid_version_string , VERSION ) )
     {
 	ErrorMessage ( __FUNCTION__  , "\
 Settings file found in your ~/.freedroid_rpg dir does not\n\
@@ -1452,12 +1382,6 @@ settings file will be generated.",
 	return (ERR);
     };
     
-    //--------------------
-    // We may print out that config was loaded successfully...
-    // This might stay in here.
-    //
-    DebugPrintf ( 0 , "\nSuccessfully loaded and enforced your personal configuration file %s.\n\n" , fname );
-    
     //--------------------
     // Now we will turn off the skills and inventory screen and that, cause
     // this should be off when the game starts...
@@ -1466,7 +1390,7 @@ settings file will be generated.",
     GameConfig . Inventory_Visible = FALSE ;
     GameConfig . SkillScreen_Visible = FALSE ;
     GameConfig . skill_explanation_screen_visible = FALSE ;
-    GameConfig . Automap_Visible = FALSE ;
+    GameConfig . Automap_Visible = TRUE ;
     
     if ( command_line_override_for_screen_resolution )
     {
@@ -1566,10 +1490,8 @@ SaveGameConfig (void)
  * This function is used for terminating freedroid.  It will close
  * the SDL submodules and exit.
  */
-void
-Terminate (int ExitCode)
+void Terminate (int ExitCode)
 {
-    DebugPrintf (2, "\nvoid Terminate(int ExitStatus) was called....");
     printf("\n----------------------------------------------------------------------");
     printf("\nTermination of freedroidRPG initiated...");
     
@@ -1578,20 +1500,9 @@ Terminate (int ExitCode)
     //
     SaveGameConfig();
 
-    // free the mixer channels...
-    // Mix_CloseAudio();
-
-    // printf("\nAnd now the final step...\n\n");
     printf("Thank you for playing freedroidRPG.\n\n");
     SDL_Quit();
     
-    //--------------------
-    // Occasionally we want the debugger to stop here.  That can be
-    // done by simply forcing a segmentation fault violation signal here,
-    // even if there hasn't been any real segmentation fault.
-    //
-    // raise ( SIGSEGV );
-
     //--------------------
     // Finally, especially on win32 systems, we should open an editor with
     // the last debug output, since people in general won't know how and where
@@ -1610,64 +1521,13 @@ Terminate (int ExitCode)
     // program has finished.
     //
     exit ( ExitCode );
-
-    return;
 }; // void Terminate ( int ExitCode )
 
-/**
- * Since numbers are not so very telling and can easily get confusing
- * we do not use numbers to reference the action from a trigger but 
- * rather we use labels already in the mission file.  However internally
- * the game needs numbers as a pointer or index in a list and therefore
- * this functions was added to go from a label to the corresponding 
- * number entry.
- */
-int
-GiveNumberToThisActionLabel ( char* ActionLabel )
-{
-  int i;
-
-  // DebugPrintf( 1 , "\nvoid ExecuteEvent ( int EventNumber ) : real function call confirmed. ");
-  // DebugPrintf( 1 , "\nvoid ExecuteEvent ( int EventNumber ) : executing event labeld : %s" , ActionLabel );
-
-  // In case of 'none' as action label, we don't do anything and return;
-  if ( strcmp ( ActionLabel , "none" ) == 0 ) return ( -1 );
-
-  //--------------------
-  // Now we find out which index the desired action has
-  //
-  for ( i = 0 ; i < MAX_TRIGGERED_ACTIONS_IN_GAME ; i++ )
-    {
-      if ( strcmp ( AllTriggeredActions[ i ].ActionLabel , ActionLabel ) == 0 ) break;
-    }
-
-  if ( i >= MAX_TRIGGERED_ACTIONS_IN_GAME )
-    {
-      fprintf( stderr, "\n\nActionLabel: '%s'\n" , ActionLabel );
-      ErrorMessage ( __FUNCTION__  , "\
-The label that should reference an action for later execution could not\n\
-be identified as valid reference to an existing action.",
-				 PLEASE_INFORM, IS_FATAL );
-    }
-
-  return ( i );
-}; // int GiveNumberToThisActionLabel ( char* ActionLabel )
-
-/**
- * This function executes an action with a label.
- */
-void 
-ExecuteActionWithLabel ( char* ActionLabel )
-{
-    ExecuteEvent( GiveNumberToThisActionLabel ( ActionLabel ) );
-}; // void ExecuteActionWithLabel ( char* ActionLabel )
-
 /**
  *
  *
  */
-obstacle* 
-give_pointer_to_obstacle_with_label ( char* obstacle_label ) 
+obstacle *give_pointer_to_obstacle_with_label ( const char* obstacle_label ) 
 {
   int i, j , k;
 
@@ -1677,6 +1537,8 @@ give_pointer_to_obstacle_with_label ( char* obstacle_label )
   //
   for ( i = 0 ; i < curShip . num_levels ; i ++ )
     {
+	  if ( curShip.AllLevels[i] == NULL ) continue;
+	  
       for ( j = 0 ; j < MAX_OBSTACLE_NAMES_PER_LEVEL ; j ++ )
 	{
 	  if ( curShip . AllLevels [ i ] -> obstacle_name_list [ j ] != NULL )
@@ -1723,8 +1585,7 @@ The obstacle label given was NOT found in any levels obstacle label list." ,
  *
  *
  */
-int
-give_level_of_obstacle_with_label ( char* obstacle_label ) 
+int give_level_of_obstacle_with_label (const char* obstacle_label ) 
 {
   int i, j , k;
 
@@ -1734,6 +1595,8 @@ give_level_of_obstacle_with_label ( char* obstacle_label )
   //
   for ( i = 0 ; i < curShip . num_levels ; i ++ )
     {
+	  if ( curShip.AllLevels[i] == NULL ) continue;
+	  
       for ( j = 0 ; j < MAX_OBSTACLE_NAMES_PER_LEVEL ; j ++ )
 	{
 	  if ( curShip . AllLevels [ i ] -> obstacle_name_list [ j ] != NULL )
@@ -1775,207 +1638,6 @@ The obstacle label given was NOT found in any levels obstacle label list." ,
 
 }; // int give_level_of_obstacle_with_label ( char* obstacle_label ) 
 
-/**
- * 
- */
-void 
-ExecuteEvent ( int EventNumber )
-{
-    obstacle* our_obstacle;
-    int obstacle_level_num ;
-    Level obstacle_level ;
-    
-    DebugPrintf( 1 , "\nvoid ExecuteEvent ( int EventNumber ) : executing event Nr.: %d." , EventNumber );
-
-    // Do nothing in case of the empty action (-1) given.
-    if ( EventNumber == (-1) ) return;
-    
-    //--------------------
-    // Maybe the action will cause a map obstacle to change type.  If that is so, we
-    // do it here...
-    //
-    if ( strlen ( AllTriggeredActions [ EventNumber ] . modify_obstacle_with_label ) > 0 )
-    {
-	our_obstacle = give_pointer_to_obstacle_with_label ( AllTriggeredActions [ EventNumber ] . modify_obstacle_with_label ) ;
-	obstacle_level_num = give_level_of_obstacle_with_label ( AllTriggeredActions [ EventNumber ] . modify_obstacle_with_label ) ;
-	obstacle_level = curShip . AllLevels [ obstacle_level_num ] ;
-	if ( AllTriggeredActions [ EventNumber ] . modify_obstacle_to_type ) {
-	    int j;
-	    int base  = obstacle_level -> obstacle_statelist_base  [ our_obstacle -> name_index ] ;
-	    int count = obstacle_level -> obstacle_statelist_count [ our_obstacle -> name_index ] ;
-	    for (j=0; j<count; j++)
-		if ( !strcmp ( obstacle_level->obstacle_states_names [ j+base ],
-			       AllTriggeredActions [ EventNumber ] . modify_obstacle_to_type) ) {
-		    our_obstacle -> type = obstacle_level->obstacle_states_values [ j+base ];
-		    break;
-		}
-	} else {
-		action_remove_obstacle (  curShip . AllLevels [ obstacle_level_num ], our_obstacle);
-	     }
-
-	//--------------------
-	// Now we make sure the door lists and that are all updated...
-	//
-	
-	GetAllAnimatedMapTiles ( curShip . AllLevels [ obstacle_level_num ] ) ;
-	//--------------------
-	// Also make sure the other maps realize the change too, if it
-	// maybe happend in the border area where two maps are glued together
-	// only export if the obstacle falls within the interface zone
-	
-	if( our_obstacle->pos.x <= obstacle_level->jump_threshold_west ||
-	    our_obstacle->pos.x >= obstacle_level->xlen - obstacle_level->jump_threshold_east ||
-	    our_obstacle->pos.y <= obstacle_level->jump_threshold_north ||
-	    our_obstacle->pos.y >= obstacle_level->ylen - obstacle_level->jump_threshold_south
-	    ) ExportLevelInterface ( obstacle_level_num ) ;
-	
-    }
-
-    // Does the action include a teleport of the influencer to some other location?
-    if ( AllTriggeredActions [ EventNumber ] . TeleportTarget . x != (-1) )
-    {
-	DebugPrintf( 1 , "\nvoid ExecuteEvent: Now a teleportation should occur!" );
-	Teleport ( AllTriggeredActions[ EventNumber ].TeleportTargetLevel ,
-		   AllTriggeredActions[ EventNumber ].TeleportTarget.x + 0.5 ,
-		   AllTriggeredActions[ EventNumber ].TeleportTarget.y + 0.5 ,
-		   TRUE );
-    }
-   
-    // Does the action show text on user screen?
-    if ( strlen ( AllTriggeredActions [ EventNumber ] . show_big_screen_message ) > 0 ){
-        SetNewBigScreenMessage ( AllTriggeredActions [ EventNumber ] . show_big_screen_message );
-	append_new_game_message ( AllTriggeredActions [ EventNumber ] . show_big_screen_message );
-    }
-
-    // Does the defined action change another action trigger?
-    if ( strlen ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_with_action_label ) > 0 )
-	{
-	//look for the target event trigger
-	event_trigger * target_event = NULL;
-	int i;
-        for ( i = 0 ; i < MAX_EVENT_TRIGGERS ; i++ )
-		{
-		if ( ! strcmp (AllEventTriggers[i].TargetActionLabel ,  AllTriggeredActions[ EventNumber ] . modify_event_trigger_with_action_label ) )
-			target_event = &AllEventTriggers[i];
-		}
-	
-	//Shall we disable the event trigger?
-	if ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_value == 0 )
-		{
-		target_event -> enabled = 0;
-		}
-
-	//Shall we enable the event trigger?
-	if ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_value == 1 )
-		{
-		target_event -> enabled = 1;
-		}
-	}
-
-   // Does the defined action run another action ?
-   if ( strlen ( AllTriggeredActions [ EventNumber ] . also_execute_action_label ) > 0 )
-	{
-	ExecuteActionWithLabel ( AllTriggeredActions [ EventNumber ] . also_execute_action_label );
-	}
-}; // void ExecuteEvent ( int EventNumber )
-
-/**
- *
- * This function checks for triggered events & statements.  Those events are
- * usually entered via the mission file and read into the apropriate
- * structures via the InitNewMission function.  Here we check, whether
- * the nescessary conditions for an event are satisfied, and in case that
- * they are, we order the apropriate event to be executed.
- *
- * In addition, statements are started, if the influencer is at the 
- * right location for them.
- *
- */
-void 
-CheckForTriggeredEventsAndStatements ( )
-{
-    int i;
-    int map_x, map_y;
-    Level StatementLevel = curShip.AllLevels[ Me . pos . z ] ;
-    
-    //--------------------
-    // Now we check if some statment location is reached
-    //
-    map_x = (int) rintf( (float) Me . pos . x ); map_y = (int) rintf( (float)Me . pos . y ) ;
-    for ( i = 0 ; i < MAX_STATEMENTS_PER_LEVEL ; i++ )
-    {
-	if ( ( map_x == StatementLevel -> StatementList [ i ] . x ) &&
-	     ( map_y == StatementLevel -> StatementList [ i ] . y ) )
-	{
-	    Me . TextVisibleTime = 0 ;
-	    Me . TextToBeDisplayed = CURLEVEL -> StatementList [ i ] . Statement_Text ;
-	}
-    }
-    
-    //--------------------
-    // Now we check if some event trigger is fullfilled.
-    //
-    for ( i = 0 ; i < MAX_EVENT_TRIGGERS ; i++ )
-    {
-	// if ( AllEventTriggers[i].EventNumber == (-1) ) continue;  // thats a sure sign this event doesn't need attention
-	if ( strcmp (AllEventTriggers[i].TargetActionLabel , "none" ) == 0 ) continue;  // thats a sure sign this event doesn't need attention
-	if ( AllEventTriggers[i].enabled == 0 ) continue;  // this trigger is not enabled
-	
-	// --------------------
-	// So at this point we know, that the event trigger is somehow meaningful. 
-	// Fine, so lets check the details, if the event is triggered now
-	//
-	
-	if ( AllEventTriggers[i].Influ_Must_Be_At_Point.x != (-1) )
-	{
-	    if ( rintf( AllEventTriggers[i].Influ_Must_Be_At_Point.x ) != (int) ( Me . pos.x ) ) continue;
-	}
-	
-	if ( AllEventTriggers[i].Influ_Must_Be_At_Point.y != (-1) )
-	{
-	    if ( rintf( AllEventTriggers[i].Influ_Must_Be_At_Point.y ) != (int) ( Me . pos.y ) ) continue;
-	}
-	
-	if ( AllEventTriggers[i].Influ_Must_Be_At_Level != (-1) )
-	{
-	    if ( rintf( AllEventTriggers[i].Influ_Must_Be_At_Level ) != StatementLevel->levelnum ) continue;
-	}
-	
-	DebugPrintf( 2 , "\nWARNING!! INFLU NOW IS AT SOME TRIGGER POINT OF SOME LOCATION-TRIGGERED EVENT!!!");
-	// ExecuteEvent( AllEventTriggers[i].EventNumber );
-	ExecuteActionWithLabel ( AllEventTriggers [ i ] . TargetActionLabel ) ;
-	
-	if ( AllEventTriggers[i].DeleteTriggerAfterExecution == 1 )
-	{
-	    // AllEventTriggers[i].EventNumber = (-1); // That should prevent the event from being executed again.
-	    AllEventTriggers[i].TargetActionLabel = "none"; // That should prevent the event from being executed again.
-	}
-    }
-
-}; // CheckForTriggeredEventsAndStatements (void )
-
-
-/*----------------------------------------------------------------------
- * Copyright (C) 1997-2001 Id Software, Inc., under GPL
- *
- * va(fmt, ...)
- * 
- * does a varargs printf into a temp buffer, so I don't need to have
- * varargs versions of all text functions.
- *----------------------------------------------------------------------*/
-char
-*va (char *format, ...)
-{
-  va_list	argptr;
-  static char	string[1024];
-  
-  va_start (argptr, format);
-  vsprintf (string, format,argptr);
-  va_end (argptr);
-  
-  return string;	
-}
-
 /*----------------------------------------------------------------------
  * try getting round endian-differences with minimal intervention
  * to the code.. 
@@ -1983,9 +1645,6 @@ char
  * read out a 2-byte short-int from give memory pointer, either using
  * the given byte-order (PCs) or SDL's 'network byte order' (Mac)
  *
- *
- * FIXME: Ideally all binar read/write should use SDLNet_Read/Write fcts, 
- * but this would imply larger changes to the code...
  *----------------------------------------------------------------------*/
 Sint16 
 ReadSint16 (void * memory)
