@@ -63,17 +63,10 @@ int quest_browser_mission_lines_needed [ MAX_MISSIONS_IN_GAME ] ;
  * This function is responsible for making a new quest diary entry 
  * visible inside the quest browser.
  */
-void
-quest_browser_enable_new_diary_entry ( int mis_num , int mis_diary_entry_num )
+void quest_browser_enable_new_diary_entry ( const char * mis_name , int mis_diary_entry_num )
 {
+    int mis_num = GetMissionIndexByName(mis_name);
 
-    if ( ( mis_num < 0 ) || ( mis_num >= MAX_MISSIONS_IN_GAME ) )
-    {
-	fprintf ( stderr , "\nmission number received: %d." , mis_num );
-	ErrorMessage ( __FUNCTION__  , "\
-There was an illegal mission number received.",
-				   PLEASE_INFORM, IS_FATAL );
-    }
     if ( ( mis_diary_entry_num < 0 ) || ( mis_diary_entry_num >= MAX_MISSION_DESCRIPTION_TEXTS ) )
     {
 	fprintf ( stderr , "\nmission diary entry number received: %d." , mis_diary_entry_num );
@@ -92,22 +85,14 @@ There was an illegal mission diary entry number received.",
  * particular mission, which is exactly what this function is responsible
  * for.
  */
-void
-quest_browser_append_mission_info ( int mis_num , int full_description )
+void quest_browser_append_mission_info (const char * mis_name , int full_description )
 {
     char temp_text[10000];
     int mission_diary_index;
+    int mis_num = GetMissionIndexByName(mis_name);
 
-    if ( ( mis_num < 0 ) || ( mis_num >= MAX_MISSIONS_IN_GAME ) )
-    {
-	fprintf ( stderr , "\nmission number received: %d." , mis_num );
-	ErrorMessage ( __FUNCTION__  , "\
-There was an illegal mission number received.",
-				   PLEASE_INFORM, IS_FATAL );
-    }
 
-    SetTextCursor ( mission_description_rect . x , 
-		    mission_description_rect . y );
+    SetTextCursor (mission_description_rect . x ,  mission_description_rect . y);
 
     strcat ( complete_mission_display_text , _("Mission: "));
     strcat ( complete_mission_display_text , _(Me . AllMissions [ mis_num ] . MissionName));
@@ -193,14 +178,14 @@ quest_browser_display_mission_list ( int list_type )
 	if ( ( list_type == QUEST_BROWSER_SHOW_OPEN_MISSIONS ) &&
 	     ( Me . AllMissions[ mis_num ] . MissionIsComplete == FALSE ) )
 	{
-	    quest_browser_append_mission_info ( mis_num , Me . AllMissions [ mis_num ] . 
+	    quest_browser_append_mission_info ( Me.AllMissions[mis_num].MissionName , Me . AllMissions [ mis_num ] . 
 						expanded_display_for_this_mission );
 	    something_was_displayed = TRUE ;
 	}
 	else if ( ( list_type == QUEST_BROWSER_SHOW_DONE_MISSIONS ) &&
 	     ( Me . AllMissions[ mis_num ] . MissionIsComplete != FALSE ) )
 	{
-	    quest_browser_append_mission_info ( mis_num , Me . AllMissions [ mis_num ] . 
+	    quest_browser_append_mission_info ( Me.AllMissions[mis_num].MissionName , Me . AllMissions [ mis_num ] . 
 						expanded_display_for_this_mission );
 	    something_was_displayed = TRUE ;
 	}
@@ -421,12 +406,10 @@ void quest_browser_interface ( void )
  * mission.  If not it returns, if yes the EndTitle/Debriefing is
  * started.
  ----------------------------------------------------------------------*/
-void 
-CheckIfMissionIsComplete (void)
+void CheckIfMissionIsComplete (void)
 {
     int ItemCounter;
     int mis_num;
-    int ActionNum;
     static int CheckMissionGrid; 
     int this_mission_seems_completed = TRUE ;
    
@@ -602,51 +585,26 @@ CheckIfMissionIsComplete (void)
 	}
 	
 	if ( this_mission_seems_completed )
-	{
-	    //--------------------
-	    // AT THIS POINT WE KNOW THAT ALL OF THE GIVEN TARGETS FOR THIS MISSION ARE FULLFILLED
-	    // We therefore mark the mission as completed
-	    //
-	    Me.AllMissions[ mis_num ].MissionIsComplete = TRUE;
-	    Mission_Status_Change_Sound ( );
-	    for ( ActionNum = 0 ; ActionNum < MAX_MISSION_TRIGGERED_ACTIONS ; ActionNum ++ )
-	    {
-		ExecuteEvent( Me.AllMissions[ mis_num ].ListOfActionsToBeTriggeredAtCompletition[ ActionNum ] );
-	    }
-	}
+	    CompleteMission(Me.AllMissions[mis_num].MissionName);
 	
     } // for AllMissions
     
 }; // void CheckIfMissionIsComplete
 
 /**
- * This function assigns a new mission to the influencer, which means 
+ * This function assigns a new mission to the player, which means 
  * that the status of the mission in the mission array is changed and
  * perhaps the mission log activated.
  */
-void 
-AssignMission( int MissNum )
+void AssignMission (const char *name)
 {
-    int j;
+    int MissNum = GetMissionIndexByName(name);
 
-    //--------------------
-    // First some sanity check for the mission number received.
-    //
-    if ( ( MissNum < 0 ) || ( MissNum >= MAX_MISSIONS_IN_GAME ) )
-    {
-	fprintf ( stderr , "\nmission number: %d." , MissNum ) ;
-	ErrorMessage ( __FUNCTION__  , "\
-There was a mission number received that is outside the range of allowed values.",
-				   PLEASE_INFORM, IS_FATAL );
-    }
-    
     Mission_Status_Change_Sound ( );
     Me . AllMissions [ MissNum ] . MissionWasAssigned = TRUE;
-    
-    for ( j = 0 ; j < MAX_MISSION_TRIGGERED_ACTIONS ; j ++ )
-    {
-	ExecuteEvent( Me . AllMissions [ MissNum ] . ListOfActionsToBeTriggeredAtAssignment [ j ] );
-    }
+   
+    if (Me . AllMissions [ MissNum ] . assignment_lua_code)
+       run_lua(Me.AllMissions[ MissNum ].assignment_lua_code);
 
     //--------------------
     // We also make visible the very first of the mission diary enties. 
@@ -655,9 +613,23 @@ There was a mission number received that is outside the range of allowed values.
     // can be assigned, so it's safe to do that automatically.
     //
     Me . AllMissions [ MissNum ] . mission_description_visible [ 0 ] = TRUE;
-    quest_browser_enable_new_diary_entry ( MissNum , 0 );
+    quest_browser_enable_new_diary_entry (name, 0);
 
-}; // void AssignMission( int MissNum );
+};
+
+/**
+ * This function marks a mission as complete
+ */
+void CompleteMission (const char *name)
+{
+    int MissNum = GetMissionIndexByName(name);
+
+    Mission_Status_Change_Sound();
+    Me.AllMissions [MissNum].MissionIsComplete = TRUE;
+
+    if (Me.AllMissions[MissNum].completion_lua_code)
+	run_lua(Me.AllMissions[MissNum].completion_lua_code);
+}
 
 /**
  * At the start of every new game, the mission info (i.e. which missions
@@ -681,6 +653,8 @@ clear_tux_mission_info ( )
 	Me . AllMissions [ MissionTargetIndex ] . MissionWasFailed = FALSE;
 	Me . AllMissions [ MissionTargetIndex ] . MissionWasAssigned = FALSE;
 
+	strcpy(Me . AllMissions [ MissionTargetIndex ] . MissionName, "");
+
 	for ( diary_entry_nr = 0 ; diary_entry_nr < MAX_MISSION_DESCRIPTION_TEXTS ; diary_entry_nr ++ )
 	{
 	    mission_diary_texts [ MissionTargetIndex ] [ diary_entry_nr ] = "" ;
@@ -699,12 +673,7 @@ void
 GetQuestList ( char* QuestListFilename )
 {
     char *EndOfMissionTargetPointer;
-    char *NextEventPointer;
     int MissionTargetIndex = 0;
-    int NumberOfEventsToTriggerAtThisAssignment;
-    int NumberOfEventsToTriggerAtThisCompletition;
-    int ActionNr;
-    char* ActionLabel;
     char* MissionTargetPointer;
     char fpath[2048];
     char* MissionFileContents;
@@ -719,7 +688,6 @@ GetQuestList ( char* QuestListFilename )
 
 #define MISSION_TARGET_NAME_INITIALIZER "Mission Name=_\""
 
-#define MISSION_AUTOMATICALLY_ASSIGN_STRING "Assign this mission to influencer automatically at start : "
 #define MISSION_TARGET_FETCH_ITEM_STRING "Mission target is to fetch item : \""
 #define MISSION_TARGET_KILL_ONE_STRING "Mission target is to kill droids with marker : "
 #define MISSION_TARGET_MUST_CLEAR_FIRST_LEVEL "Mission target is to kill all hostile droids this first level : "
@@ -731,8 +699,8 @@ GetQuestList ( char* QuestListFilename )
 #define MISSION_TARGET_MUST_BE_TYPE_STRING "Mission target is to become type : "
 #define MISSION_TARGET_MUST_BE_ONE_STRING "Mission target is to overtake a droid with marker : "
 
-#define MISSION_ASSIGNMENT_TRIGGERED_ACTION_STRING "On mission assignment immediately trigger action Nr. : "
-#define MISSION_COMPLETITION_TRIGGERED_ACTION_STRING "On mission completition immediately trigger action labeled=\""
+#define MISSION_ASSIGNMENT_LUACODE_STRING "Assignment LuaCode={"
+#define MISSION_COMPLETION_LUACODE_STRING "Completion LuaCode={"
 #define MISSION_DIARY_ENTRY_STRING "Mission diary entry=_\""
 
     //--------------------
@@ -764,22 +732,9 @@ GetQuestList ( char* QuestListFilename )
 	
 	Me . AllMissions [ MissionTargetIndex ] . MissionExistsAtAll = TRUE;
 	
-	// Me.AllMissions[ MissionTargetIndex ].MissionName = 
-	// ReadAndMallocStringFromData ( MissionTargetPointer , MISSION_TARGET_NAME_INITIALIZER , "\"" ) ;
 	char * tmname =  ReadAndMallocStringFromData ( MissionTargetPointer , MISSION_TARGET_NAME_INITIALIZER , "\"" );
 	strcpy ( Me.AllMissions[ MissionTargetIndex ].MissionName , tmname ) ;
 	free ( tmname ) ;
-	//--------------------
-	// No we read in if this mission should be assigned to the influencer
-	// automatically at the game start and without the influencer having to apply
-	// for the mission first.
-	//
-	// The assignment however will take at the end of this mission list initialisation function,
-	// cause we need the rest of the mission target data and the events to properly 'assign' the mission.
-	// 
-	ReadValueFromString( MissionTargetPointer , MISSION_AUTOMATICALLY_ASSIGN_STRING , "%d" , 
-			     &Me.AllMissions[ MissionTargetIndex ].AutomaticallyAssignThisMissionAtGameStart , 
-			     EndOfMissionTargetPointer );
 	
 	//--------------------
 	// From here on we read the details of the mission target, i.e. what the
@@ -820,61 +775,17 @@ GetQuestList ( char* QuestListFilename )
 	ReadValueFromString( MissionTargetPointer , MISSION_TARGET_MUST_LIVE_TIME_STRING , "%lf" , 
 			     &Me.AllMissions[ MissionTargetIndex ].MustLiveTime , EndOfMissionTargetPointer );
 	
-	//--------------------
-	// At this point we have read in the target values.  Now it is time to
-	// read in the events, that need to be triggered immediately after the mission has been
-	// assigned.
-	//
-	// But first we initialize all the actions to be triggered with -1
-	//
-	for ( ActionNr = 0 ; ActionNr < MAX_MISSION_TRIGGERED_ACTIONS; ActionNr ++ )
-	{
-	    Me.AllMissions[ MissionTargetIndex ].ListOfActionsToBeTriggeredAtAssignment[ ActionNr ] = (-1) ;
+	if (strstr(MissionTargetPointer, MISSION_COMPLETION_LUACODE_STRING)) {
+	    Me.AllMissions[MissionTargetIndex].completion_lua_code = ReadAndMallocStringFromData(MissionTargetPointer, MISSION_COMPLETION_LUACODE_STRING, "}");
+	} else {
+	    Me.AllMissions[MissionTargetIndex].completion_lua_code = NULL;
 	}
-	
-	NextEventPointer = MissionTargetPointer;
-	NumberOfEventsToTriggerAtThisAssignment = 0;
-	while ( ( NextEventPointer = strstr( NextEventPointer , MISSION_ASSIGNMENT_TRIGGERED_ACTION_STRING ) ) != NULL )
-	{
-	    
-	    ReadValueFromString( NextEventPointer , MISSION_ASSIGNMENT_TRIGGERED_ACTION_STRING , "%d" ,
-				 &Me.AllMissions[ MissionTargetIndex ].ListOfActionsToBeTriggeredAtAssignment[ NumberOfEventsToTriggerAtThisAssignment ] ,
-				 EndOfMissionTargetPointer );
-	    
-	    
-	    NumberOfEventsToTriggerAtThisAssignment ++;
-	    NextEventPointer ++;
+
+	if (strstr(MissionTargetPointer, MISSION_ASSIGNMENT_LUACODE_STRING)) {
+	    Me.AllMissions[MissionTargetIndex].assignment_lua_code = ReadAndMallocStringFromData(MissionTargetPointer, MISSION_ASSIGNMENT_LUACODE_STRING, "}");
+	} else {
+	    Me.AllMissions[MissionTargetIndex].assignment_lua_code = NULL;
 	}
-	DebugPrintf ( 1 , "\nDetected %d events to be triggered at this assignment." , 
-		      NumberOfEventsToTriggerAtThisAssignment ) ;
-	
-	//--------------------
-	// Now it is time to read in the events, that need to be triggered immediately after the
-	// mission has been completed.
-	//
-	// But first we initialize all the actions to be triggered with -1
-	//
-	for ( ActionNr = 0 ; ActionNr < MAX_MISSION_TRIGGERED_ACTIONS; ActionNr ++ )
-	{
-	    Me.AllMissions[ MissionTargetIndex ].ListOfActionsToBeTriggeredAtCompletition[ ActionNr ] = (-1) ;
-	}
-	NextEventPointer = MissionTargetPointer;
-	NumberOfEventsToTriggerAtThisCompletition = 0;
-	while ( ( NextEventPointer = strstr( NextEventPointer , MISSION_COMPLETITION_TRIGGERED_ACTION_STRING ) ) != NULL )
-	{
-	    
-	    ActionLabel=
-		ReadAndMallocStringFromData ( NextEventPointer , MISSION_COMPLETITION_TRIGGERED_ACTION_STRING , "\"" ) ;
-	    
-	    Me . AllMissions [ MissionTargetIndex ] . ListOfActionsToBeTriggeredAtCompletition [ NumberOfEventsToTriggerAtThisCompletition ] = GiveNumberToThisActionLabel ( ActionLabel );
-	    
-	    NumberOfEventsToTriggerAtThisCompletition ++;
-	    NextEventPointer ++;
-	    free ( ActionLabel );
-	}
-	DebugPrintf ( 1 , "\nDetected %d events to be triggered at this mission completition." , 
-		      NumberOfEventsToTriggerAtThisCompletition );
-	
 	//--------------------
 	// Now it is time to read in the mission diary entries, that might
 	// be displayed in the quest browser later.
@@ -924,5 +835,21 @@ GetQuestList ( char* QuestListFilename )
     free ( MissionFileContents );
 }; // void Get_Mission_Targets( ... )
 
+/**
+ * This function returns the mission that has the specified name.
+ */
+int GetMissionIndexByName (const char *name)
+{
+    int cidx;
+
+    for (cidx=0; cidx < MAX_MISSIONS_IN_GAME; cidx++) {
+	if (!strcmp(Me.AllMissions[cidx].MissionName, name))
+	    return cidx;
+    }
+
+    ErrorMessage(__FUNCTION__, "Unable to find mission named %s\n", PLEASE_INFORM, IS_FATAL, name);
+    return -1;
+}
+
 
 #undef _mission_c
