@@ -38,8 +38,6 @@
 #include "SDL_rotozoom.h"
 
 // 28 degress is the magic angle for our iso view
-#define COS_45 0.707106
-#define SIN_45 0.707106
 #define COS_28 0.88294759
 #define SIN_28 0.46947156
 
@@ -78,81 +76,57 @@ our_SDL_blit_surface_wrapper(SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *d
 #ifdef HAVE_LIBGL
 	if ( src == NULL ) 
 	{
-	    DebugPrintf ( -4 , "\nNull source surface received. --> doing nothing." );
-	    fflush ( stdout );
-	    raise ( SIGSEGV );
+	    ErrorMessage ( __FUNCTION__, "Got NULL as source surface. src = 0x%08x, dstrect = 0x%08x x = %d y = %d w = %d h = %d.", PLEASE_INFORM, IS_FATAL, src, dstrect, dstrect ? dstrect->x : -1, dstrect ? dstrect->y : -1, dstrect ? dstrect->w : -1, dstrect ? dstrect->h : -1);
 	    return ( 0 );
 	}
 	
 	if ( dst == Screen )
 	{
-	    
-	    // DebugPrintf ( -1 , "\nReached our_SDL_blit_surface_wrapper." );
-	    // fflush ( stdout );
-	    
 	    if ( dstrect == NULL )
 		glRasterPos2i( 0 , GameConfig . screen_height - 1 );
 	    else
 	    {
-		if ( dstrect -> x == 0 )
-		    target_x = 0 ;
-		else
-		    target_x = dstrect -> x ;
-		
+		target_x = dstrect -> x ;
 		target_y = dstrect -> y + src -> h ;
 		
-		//--------------------
-		// Here we add some extra security against raster positions (e.g. for
-		// character screen and the like) SLIGHTLY out of bounds, which would
-		// cause the entire blit to be canceled due to OpenGL internal policy.
-		//
-		if ( ( target_y >= 480 ) && ( target_y <= 482 ) ) target_y = 478 ; 
-		
 		glRasterPos2i( target_x , target_y ) ;
 	    }
-	    
-	    if ( src -> w != 0 )
-		bytes = src -> pitch / src -> w ;
-	    else
-	    {
-		DebugPrintf ( -4 , "\nSurface of width 0 encountered. --> doing nothing." );
-		fflush ( stdout );
-		return ( 0 ) ;
+
+	    // error cases
+	    if (!src->w) {
+		    ErrorMessage(__FUNCTION__, "Surface of width 0 encountered, doing nothing.", NO_NEED_TO_INFORM, IS_WARNING_ONLY);
+		    return 0;
 	    }
-	    
-	    if ( srcrect != NULL )
-	    {
-		DebugPrintf ( -4 , "\nNon-Null source rect encountered. --> doing nothing." );
-		fflush ( stdout );
-		return ( 0 ) ;
+
+	    if (srcrect != NULL) {
+		    ErrorMessage(__FUNCTION__, "srcrect is not NULL, we do not handle this.", NO_NEED_TO_INFORM, IS_WARNING_ONLY);
+		    return 0;
 	    }
-	    
+
+	    bytes = src -> pitch / src -> w ;
+
 	    glDisable ( GL_TEXTURE_2D ); 
+	    glEnable( GL_ALPHA_TEST );  
 
-	    if ( bytes == 4 )
-	    {
-		glEnable( GL_ALPHA_TEST );  
-		glDrawPixels( src -> w , src -> h, GL_BGRA , GL_UNSIGNED_BYTE , src -> pixels );		
-		glDisable( GL_ALPHA_TEST );  
+		switch (bytes) {
+			case 4:
+#if SDL_BYTEORDER == SDL_BIG_ENDIAN
+				glDrawPixels( src -> w , src -> h, GL_BGRA , GL_UNSIGNED_INT_8_8_8_8, src -> pixels );
+#else	
+				glDrawPixels( src -> w , src -> h, GL_BGRA , GL_UNSIGNED_BYTE, src -> pixels );	
+#endif
+				break;
+			case 3: 
+				glDrawPixels( src -> w , src -> h, GL_RGB , GL_UNSIGNED_BYTE , src -> pixels );
+				break;
+			case 2:
+				glDrawPixels( src -> w , src -> h, GL_RGB , GL_UNSIGNED_SHORT_5_6_5 , src -> pixels );
+				break;
+			default:
+				ErrorMessage(__FUNCTION__, "Surface has %d bytes per pixel. Doing nothing.", NO_NEED_TO_INFORM, IS_WARNING_ONLY);
+		}
 
-	    }
-	    else if ( bytes == 3 )
-	    {
-		DebugPrintf ( 1 , "\nSurface has bytes: %d. " , bytes );
-		fflush ( stdout );
-		glDrawPixels( src -> w , src -> h, GL_RGB , GL_UNSIGNED_BYTE , src -> pixels );
-	    }
-	    else if ( bytes == 2 )
-	    {
-		DebugPrintf ( 1 , "\nSurface has bytes: %d. --> using GL_UNSIGNED_SHORT_5_6_5. " , bytes );
-		fflush ( stdout );
-		glDrawPixels( src -> w , src -> h, GL_RGB , GL_UNSIGNED_SHORT_5_6_5 , src -> pixels );
-	    }
-	    else
-	    {
-		DebugPrintf ( -4 , "\nSurface has bytes: %d.--> doing nothing. " , bytes );
-		fflush ( stdout );
-	    }
+	    glDisable( GL_ALPHA_TEST );  
 	    glEnable ( GL_TEXTURE_2D );  
 	    return ( 0 ) ;
 	}
@@ -166,7 +140,6 @@ our_SDL_blit_surface_wrapper(SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *d
     }
     
     return 0 ;
-    
 }; // void our_SDL_blit_surface_wrapper(image, NULL, Screen, NULL)
 
 /**
@@ -178,7 +151,7 @@ our_SDL_update_rect_wrapper ( SDL_Surface *screen, Sint32 x, Sint32 y, Sint32 w,
 {
   if ( use_open_gl )
     {
-      our_SDL_flip_wrapper ( screen ) ;
+      our_SDL_flip_wrapper () ;
     }
   else
     {
@@ -271,7 +244,6 @@ blit_quad ( int x1 , int y1 , int x2, int y2, int x3, int y3, int x4 , int y4 ,
 	glEnd( );
 
 	glEnable( GL_TEXTURE_2D );
-	return ( 0 );
 #endif
     }
 
@@ -515,34 +487,19 @@ pad_image_for_texture ( SDL_Surface* our_surface )
  * make_texture_out_of_surface and make_texture_out_of_prepadded_image are
  * the entry points for this function.
  */
-static void
-do_make_texture_out_of_surface ( iso_image* our_image, int txw, int txh, void * data) 
+static void do_make_texture_out_of_surface ( iso_image* our_image, int txw, int txh, void * data) 
 {
 
 #ifdef HAVE_LIBGL
 
     glPixelStorei ( GL_UNPACK_ALIGNMENT , 1 );
     
-    if ( our_image-> texture )
+    if (! our_image-> texture )
 	{
-	goto reuse_tex;
+	glGenTextures(1, &our_image->texture);
 	}
 
-    our_image -> texture = all_freedroid_textures [ next_texture_index_to_use ] ;
-    our_image -> texture_has_been_created = TRUE ;
-    next_texture_index_to_use ++ ;
-    if ( next_texture_index_to_use >= MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE )
-    {
-	ErrorMessage ( __FUNCTION__  , 
-				   "Ran out of initialized texture positions to use for new textures.",
-				   PLEASE_INFORM, IS_FATAL );
-    }
-    else
-    {
-	DebugPrintf ( 1 , "\nTexture positions remaining: %d." , MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE - next_texture_index_to_use );
-    }
-    
-    reuse_tex:
+    our_image -> texture_has_been_created = TRUE;
     DebugPrintf ( 1 , "Using texture %d\n", our_image->texture);
    
     glBindTexture( GL_TEXTURE_2D, ( our_image -> texture ) );
@@ -566,8 +523,7 @@ do_make_texture_out_of_surface ( iso_image* our_image, int txw, int txh, void *
 
 }
 
-void
-make_texture_out_of_surface ( iso_image* our_image ) 
+void make_texture_out_of_surface ( iso_image* our_image ) 
 {
 
 #ifdef HAVE_LIBGL
@@ -765,10 +721,6 @@ safely_initialize_our_default_open_gl_parameters ( void )
     
     safely_set_some_open_gl_flags_and_shade_model ();
     
-    glGenTextures( MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE , & ( all_freedroid_textures [ 0 ] ) );  
-    
-    next_texture_index_to_use = 0 ;
-
     glGetIntegerv(GL_MAX_TEXTURE_SIZE, &gl_max_texture_size);
     
     open_gl_check_error_status ( __FUNCTION__ );
@@ -1022,14 +974,7 @@ StoreMenuBackground ( int backup_slot )
 
 	if ( StoredMenuBackgroundTex [ backup_slot ] == 0 )
 		{ 
-		StoredMenuBackgroundTex [ backup_slot ] = all_freedroid_textures [ next_texture_index_to_use ] ;
-	        next_texture_index_to_use ++ ;
-		if ( next_texture_index_to_use >= MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE )
-		    {
-                    ErrorMessage ( __FUNCTION__  ,
-                                   "Ran out of initialized texture positions to use for new textures.",
-                                   PLEASE_INFORM, IS_FATAL );
-                    } 
+		glGenTextures(1, &StoredMenuBackgroundTex[backup_slot]);
 		}
 
 	glEnable(GL_TEXTURE_2D);
@@ -1073,8 +1018,7 @@ StoreMenuBackground ( int backup_slot )
  * can be stretched out over the whole screen via OpenGL.
  * This function is here to set up the texture in the first place.
  */
-void
-set_up_stretched_texture_for_light_radius ( void )
+void set_up_stretched_texture_for_light_radius ( void )
 {
 #ifdef HAVE_LIBGL
 
@@ -1103,20 +1047,8 @@ set_up_stretched_texture_for_light_radius ( void )
     //
     glPixelStorei( GL_UNPACK_ALIGNMENT , 1 );
 
-    light_radius_stretch_texture = all_freedroid_textures [ next_texture_index_to_use ] ;
-    next_texture_index_to_use ++ ;
+    glGenTextures(1, &light_radius_stretch_texture);
 
-    if ( next_texture_index_to_use >= MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE )
-    {
-	ErrorMessage ( __FUNCTION__  , 
-				   "Ran out of initialized texture positions to use for new textures.",
-				   PLEASE_INFORM, IS_FATAL );
-    }
-    else
-    {
-	DebugPrintf ( 0 , "\nTexture positions remaining: %d." , MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE - next_texture_index_to_use );
-    }
-    
     glBindTexture( GL_TEXTURE_2D, ( light_radius_stretch_texture ) );
   
     glTexParameteri( GL_TEXTURE_2D , GL_TEXTURE_MAG_FILTER , GL_LINEAR );
