@@ -29,8 +29,6 @@
 
 #define _saveloadgame_c
 
-#include <langinfo.h>
-
 #include "system.h"
 
 #include "defs.h"
@@ -41,6 +39,15 @@
 #include "sys/stat.h"
 #include "savestruct.h"
 
+#ifdef HAVE_LANGINFO_H
+#include <langinfo.h>
+#endif
+
+#ifndef HAVE_NL_LANGINFO
+#define nl_langinfo(X) "%a %b %e %H:%M:%S %Y"
+#endif
+
+
 #define SAVEDGAME_EXT ".savegame"
 #define SAVE_GAME_THUMBNAIL_EXT ".thumbnail.bmp"
 
@@ -77,8 +84,7 @@ ShowSaveLoadGameProgressMeter( int Percentage , int IsSavegame )
 
 }; // void ShowSaveGameProgressMeter( int Percentage ) 
 
-void
-LoadAndShowThumbnail ( char* CoreFilename )
+void LoadAndShowThumbnail ( char* CoreFilename )
 {
     char filename[1000];
     SDL_Surface* NewThumbnail;
@@ -112,8 +118,7 @@ LoadAndShowThumbnail ( char* CoreFilename )
  * 
  *
  */
-void
-LoadAndShowStats ( char* CoreFilename )
+void LoadAndShowStats ( char* CoreFilename )
 {
     char filename[1000];
     struct stat FileInfoBuffer;
@@ -146,8 +151,8 @@ or file permissions of ~/.freedroid_rpg are somehow not right.",
     LocalTimeSplitup = localtime ( & ( FileInfoBuffer.st_mtime ) ) ;
     strftime (InfoString, sizeof(InfoString), nl_langinfo (D_T_FMT), LocalTimeSplitup);
 
-    PutString ( Screen , 240 , GameConfig . screen_height - 3 * FontHeight ( GetCurrentFont () ) , _("Last Modified:") );
-    PutString ( Screen , 240 , GameConfig . screen_height - 2 * FontHeight ( GetCurrentFont () ) , InfoString );
+    PutString ( Screen , UNIVERSAL_COORD_W(240) , GameConfig . screen_height - 3 * FontHeight ( GetCurrentFont () ) , _("Last Modified:") );
+    PutString ( Screen , UNIVERSAL_COORD_W(240) , GameConfig . screen_height - 2 * FontHeight ( GetCurrentFont () ) , InfoString );
     
     //--------------------
     // Now that the modification time has been set up, we can start to compute
@@ -183,8 +188,7 @@ or file permissions of ~/.freedroid_rpg are somehow not right.",
     sprintf( InfoString , _("File Size: %2.3f MB") , 
 	     ((float)FileSize) / ( 1024.0 * 1024.0 ) );
     
-    // PutString ( Screen , 240 , GameConfig . screen_height - 2 * FontHeight ( GetCurrentFont () ) , "File Size:" );
-    PutString ( Screen , 240 , GameConfig . screen_height - 1 * FontHeight ( GetCurrentFont () ) , InfoString );
+    PutString ( Screen , UNIVERSAL_COORD_W(240) , GameConfig . screen_height - 1 * FontHeight ( GetCurrentFont () ) , InfoString );
     
 }; // void LoadAndShowStats ( char* filename );
 
@@ -253,6 +257,7 @@ int SaveGame( void )
 {
     char filename[1000];
     char filename2[1000];
+    int ret;
     
     if ( Me . energy <= 0 )
     {
@@ -267,7 +272,7 @@ int SaveGame( void )
     
     ShowSaveLoadGameProgressMeter( 0 , TRUE ) ;
     
-    sprintf ( Me . freedroid_version_string , 
+    sprintf ( Me . savegame_version_string , 
 	      "%s;sizeof(tux_t)=%d;sizeof(enemy)=%d;sizeof(bullet)=%d;MAXBULLETS=%d\n", 
 	      VERSION , 
 	      (int) sizeof(tux_t) , 
@@ -278,7 +283,12 @@ int SaveGame( void )
     sprintf( filename , "%s/%s%s", our_config_dir, Me.character_name, ".shp" );
     sprintf( filename2 , "%s/%s%s", our_config_dir, Me.character_name, ".bkp.shp" );
 
-    rename(filename, filename2);
+    unlink(filename2);
+    ret = rename(filename, filename2);
+
+    if (ret && errno != ENOENT) {
+	ErrorMessage ( __FUNCTION__, "Unable to create the shipfile backup\n", PLEASE_INFORM, IS_WARNING_ONLY);
+    }
 
     if ( SaveShip( filename ) != OK )
     {
@@ -296,7 +306,12 @@ or file permissions of ~/.freedroid_rpg are somehow not right.",
     sprintf ( filename , "%s/%s%s", our_config_dir , Me.character_name, ".savegame");
     sprintf( filename2 , "%s/%s%s", our_config_dir, Me.character_name, ".bkp.savegame" );
 
-    rename(filename, filename2);
+    unlink(filename2);
+    ret = rename(filename, filename2);
+
+    if (ret && errno != ENOENT) {
+	ErrorMessage ( __FUNCTION__, "Unable to create the savegame backup\n", PLEASE_INFORM, IS_WARNING_ONLY);
+    }
     
     if( ( SaveGameFile = fopen(filename, "wb")) == NULL) {
 	printf(_("\n\nError opening save game file for writing...\n\nTerminating...\n\n"));
@@ -305,7 +320,7 @@ or file permissions of ~/.freedroid_rpg are somehow not right.",
     
     
     /* Write the version string */
-    fprintf(SaveGameFile, "Version string: %s\n\n", Me . freedroid_version_string);
+    fprintf(SaveGameFile, "Version string: %s\n\n", Me . savegame_version_string);
     
     /* Save tux*/
     save_tux_t("player", &Me);
@@ -466,7 +481,7 @@ LoadGame( void )
     int a = 0;
     for ( i = 0 ; i < 2; i ++ )
 	{
-	char * cpos = LoadGameData;
+	volatile char * cpos = LoadGameData;
 	done = 0;
 	while ( ! done ) 
 	    {
@@ -496,7 +511,7 @@ LoadGame( void )
 
 
     /* read bullets */
-    char * cpos = LoadGameData;
+    volatile char * cpos = LoadGameData;
     done = 0;
     for ( i = 0; i < MAXBULLETS && ! done ; i ++)
 	{
@@ -536,9 +551,9 @@ LoadGame( void )
 	      (int) sizeof(bullet) ,
 	      (int) MAXBULLETS );
     
-    if ( strcmp ( Me . freedroid_version_string , version_check_string ) != 0 )
+    if ( strcmp ( Me . savegame_version_string , version_check_string ) != 0 )
     {
-	show_button_tooltip ( _("Version or structsize mismatch! The savegame is not from the same version of freedroidRPG... possible breakage.\n") );
+	GiveMouseAlertWindow( _("Version or structsize mismatch! The savegame is not from the same version of freedroidRPG... possible breakage.\n") );
 	our_SDL_flip_wrapper();
 	while ( ! MouseLeftPressed() ) SDL_Delay(1);
     }
@@ -677,6 +692,32 @@ void read_string(const char * buffer, const char * tag, char * val)
     *epos = '\n';
 }
 
+void save_luacode(const char * tag, luacode * val)
+{
+    if (*val)
+	fprintf(SaveGameFile, "%s:LuaCode={%s}\n", tag, *val);
+}
+
+void read_luacode(const char * buffer, const char * tag, luacode * val)
+{
+    if (*val) {
+	free(*val);
+	*val = NULL;
+    }
+
+    char search[strlen(tag) + 3];
+    sprintf(search, "\n%s:LuaCode={", tag);
+    char * pos = strstr(buffer, search);
+    if ( ! pos ) return;
+    while (*pos != '{') pos++;
+    pos++;
+    char * epos = pos;
+    while ( *epos != '}' || *(epos+1) != '\n') epos++;
+    *epos = '\0';
+    *val = malloc(strlen(pos)+1);
+    strcpy ( *val, pos );
+    *epos = '\n';
+}
 
 /* Save arrays of simple types */
 #define define_save_xxx_array(X) void save_##X##_array(const char * tag, X * val_ar, int size)\
@@ -821,19 +862,37 @@ while ( *erunp != '>' ) erunp ++;
 ma = atoi(runp);
 *erunp = '>';
 
-if ( mp != MAX_PERSONS )  
-    WrapErrorMessage ( __FUNCTION__, "MAX_PERSONS mismatch for array ChatFlags, %d in file, %d in game\n", PLEASE_INFORM, IS_FATAL, mp, MAX_PERSONS);
-if ( ma != MAX_ANSWERS_PER_PERSON )
-    WrapErrorMessage ( __FUNCTION__, "MAX_ANSWERS_PER_PERSON mismatch for array ChatFlags, %d in file, %d in game\n", PLEASE_INFORM, IS_FATAL, ma, MAX_ANSWERS_PER_PERSON);
+if ( mp != MAX_PERSONS )  {
+    /* If the savegame array is smaller than the game array, this is not a fatal error, however breakage is highly
+     * likely to occur in any case. */
+    int inf = PLEASE_INFORM;
+    int fat = IS_FATAL;
+    if (mp < MAX_PERSONS) {
+	inf = NO_NEED_TO_INFORM;
+	fat = IS_WARNING_ONLY;
+    }
+
+    WrapErrorMessage ( __FUNCTION__, "MAX_PERSONS mismatch for array ChatFlags, %d in file, %d in game\n", inf, fat, mp, MAX_PERSONS);
+}
+
+if ( ma != MAX_ANSWERS_PER_PERSON ) {
+    int inf = PLEASE_INFORM;
+    int fat = IS_FATAL;
+    if (ma < MAX_ANSWERS_PER_PERSON) {
+	inf = NO_NEED_TO_INFORM;
+	fat = IS_WARNING_ONLY;
+    }
+    WrapErrorMessage ( __FUNCTION__, "MAX_ANSWERS_PER_PERSON mismatch for array ChatFlags, %d in file, %d in game\n", inf, fat, ma, MAX_ANSWERS_PER_PERSON);
+}
 
 while ( *runp != '\n' ) runp++;
 runp++;
 
 int i = 0, j;
-while ( i < MAX_PERSONS )
+while ( i < mp )
 	{
 	j = 0;
-	while ( j < MAX_ANSWERS_PER_PERSON )
+	while ( j < ma )
 	    {
 	    while ( ! isdigit(*runp) ) runp++;
 	    erunp = runp + 1;
@@ -1070,14 +1129,15 @@ void read_automap_data_t_array(char * buffer, char * tag, automap_data_t * autom
     char *runp = pos + 1;
     runp += strlen("<automap");
 
-
+    ClearAutomapData();
+    
     while ( *runp != '\n' ) runp++;
     *runp = '\0';
     int nl, sx, sy;
     sscanf(pos, "<automap nl=%d sx=%d sy=%d>", &nl, &sx, &sy);
   
     if ( nl != MAX_LEVELS )
-	WrapErrorMessage(__FUNCTION__, "Number of levels mismatch when reading automap data : file %d, game %d\n", PLEASE_INFORM, IS_FATAL, nl, MAX_LEVELS);
+    	WrapErrorMessage(__FUNCTION__, "Number of levels mismatch when reading automap data : file %d, game %d\n", NO_NEED_TO_INFORM, IS_WARNING_ONLY, nl, MAX_LEVELS);
     if ( sx != 100 || sy != 100 )
 	WrapErrorMessage(__FUNCTION__, "Size mismatch when reading automap data.\n", PLEASE_INFORM, IS_FATAL);
 
@@ -1085,7 +1145,7 @@ void read_automap_data_t_array(char * buffer, char * tag, automap_data_t * autom
     runp++;
     char * erunp;
     int i = 0, j = 0, k = 0;
-    while ( i < MAX_LEVELS )
+    while ( i < nl )
 	{
 	/* we're on level number */
 	while ( *runp != '\n' ) runp++;
@@ -1114,7 +1174,7 @@ void read_automap_data_t_array(char * buffer, char * tag, automap_data_t * autom
 
 	while ( *runp != '\n' ) runp++;
 	i++;
-	}
+    }
     *(epos+1) = savechar;
 
 }
