@@ -10,15 +10,13 @@ int save_mission(char *, mission *);
  int read_mission(char *, char *, mission *);
 int save_tux_t(char *, tux_t *);
  int read_tux_t(char *, char *, tux_t *);
-int save_configuration_for_freedroid(char *, configuration_for_freedroid *);
- int read_configuration_for_freedroid(char *, char *, configuration_for_freedroid *);
-int save_finepoint(char *, finepoint *);
- int read_finepoint(char *, char *, finepoint *);
 int save_item(char *, item *);
  int read_item(char *, char *, item *);
+int save_finepoint(char *, finepoint *);
+ int read_finepoint(char *, char *, finepoint *);
 int save_melee_shot(char *, melee_shot *);
  int read_melee_shot(char *, char *, melee_shot *);
-int save_keybind_t(char *, keybind_t *);
- int read_keybind_t(char *, char *, keybind_t *);
+int save_configuration_for_freedroid(char *, configuration_for_freedroid *);
+ int read_configuration_for_freedroid(char *, char *, configuration_for_freedroid *);
 int save_gps(char *, gps *);
  int read_gps(char *, char *, gps *);
